@@ -9,10 +9,13 @@
 
 #include "skeleton/msgdiag.h"
 
+#include "message/messageadmin.h"
+
 #include "dbtree/interface.h"
 #include "dbtree/articlebase.h"
 
 #include "jdlib/miscutil.h"
+#include "jdlib/misctime.h"
 
 #include "config/globalconf.h"
 
@@ -43,7 +46,7 @@ enum
 // メインビュー
 
 ArticleViewMain::ArticleViewMain( const std::string& url )
-    :  ArticleViewBase( url ), m_gotonum_reserve( 0 ), m_gotonum_seen( 0 ), m_playsound( false )
+    :  ArticleViewBase( url, url ), m_gotonum_reserve_to( 0 ), m_gotonum_reserve_from( 0 ), m_gotonum_seen( 0 ), m_playsound( false ), m_reload_reserve( false )
 {
 #ifdef _DEBUG
     std::cout << "ArticleViewMain::ArticleViewMain " << get_url() << " url_article = " << url_article() << std::endl;
@@ -70,6 +73,22 @@ ArticleViewMain::~ArticleViewMain()
 #ifdef _DEBUG    
     std::cout << "ArticleViewMain::~ArticleViewMain : " << get_url() << " url_article = " << url_article() << std::endl;
 #endif
+
+    save_session();
+
+    // 閉じたタブ履歴更新
+    HISTORY::append_history( URL_HISTCLOSEVIEW,
+                             DBTREE::url_dat( get_url() ),
+                             DBTREE::article_subject( get_url() ), TYPE_THREAD );
+
+    CORE::core_set_command( "close_message" ,url_article() );
+
+    if( get_live() ) live_stop();
+}
+
+
+void ArticleViewMain::save_session()
+{
     const int seen = drawarea()->get_seen_current();
         
 #ifdef _DEBUG    
@@ -77,13 +96,6 @@ ArticleViewMain::~ArticleViewMain()
 #endif
 
     if( seen >= 1 ) get_article()->set_number_seen( seen );
-
-    // 閉じたタブ履歴更新
-    HISTORY::append_history( URL_HISTCLOSEVIEW,
-                             DBTREE::url_dat( get_url() ),
-                             DBTREE::article_subject( get_url() ), TYPE_THREAD );
-
-    if( get_live() ) live_stop();
 }
 
 
@@ -94,6 +106,17 @@ void ArticleViewMain::clock_in()
 
     // 実況モードでリロード
     if( get_live() && ! is_loading() && inc_autoreload_counter() ) exec_reload();
+
+    // 更新チェック中にshow_view()が呼び出された場合は
+    // チェックが終わってから改めてロードする
+    if( m_reload_reserve ){
+
+        if( ! get_article()->is_checking_update() ){
+
+            m_reload_reserve = false;
+            show_view();
+        }
+    }
 }
 
 
@@ -102,16 +125,18 @@ void ArticleViewMain::clock_in()
 //
 // ローディング中ならジャンプ予約をしてロード後に update_finish() の中で改めて goto_num() を呼び出す
 //
-void ArticleViewMain::goto_num( int num )
+void ArticleViewMain::goto_num( const int num_to, const int num_from )
 {
 #ifdef _DEBUG
-    std::cout << "ArticleViewMain::goto_num num = " << num << " seen = " << m_gotonum_seen << " res = " << m_gotonum_reserve << std::endl;
+    std::cout << "ArticleViewMain::goto_num num = " << num_to << " num_from " << num_from
+              << " gotonum_seen = " << m_gotonum_seen << " gotonum_reserve = " << m_gotonum_reserve_to << std::endl;
 #endif
 
-    m_gotonum_seen = 0; // m_gotonum_reserve を優先させる
-    m_gotonum_reserve = num;
+    m_gotonum_seen = 0; // m_gotonum_reserve_to を優先させる
+    m_gotonum_reserve_to = num_to;
+    m_gotonum_reserve_from = num_from;
 
-    if( get_article()->get_number_load() < num  && is_loading() ){
+    if( get_article()->get_number_load() < num_to  && is_loading() ){
 #ifdef _DEBUG
         std::cout << "reserve\n";
 #endif
@@ -122,7 +147,7 @@ void ArticleViewMain::goto_num( int num )
     std::cout << "jump\n";
 #endif
 
-    ArticleViewBase::goto_num( num );
+    ArticleViewBase::goto_num( num_to, num_from );
 }
 
 
@@ -197,9 +222,32 @@ void ArticleViewMain::exec_reload()
 //
 void ArticleViewMain::show_view()
 {
+    // 更新チェック中の場合はチェックが終わってからclock_in()でロードする
+    if( get_article()->is_checking_update() ){
+        m_reload_reserve = true;
+        return;
+    }
+
     if( is_loading() ) return;
 
-    m_gotonum_reserve = 0;
+    // キャッシュを削除してからスレを再読み込み
+    if( SESSION::is_online() && get_reget() ){
+
+        int jump_to = drawarea()->get_seen_current();
+        if( ! jump_to ) jump_to = get_article()->get_number_seen();
+
+#ifdef _DEBUG
+        std::cout << "ArticleViewMain::show_view reget url_article = " << url_article()
+                  << " jump_to = " << jump_to << std::endl;
+#endif
+
+        set_reget( false );
+        CORE::core_set_command( "delete_article", url_article(), "reget", MISC::itostr( jump_to ) );        
+        return;
+    }
+
+    m_gotonum_reserve_to = 0;
+    m_gotonum_reserve_from = 0;
     m_gotonum_seen = 0;
     m_set_history = false;
     m_show_instdialog = false;
@@ -219,11 +267,14 @@ void ArticleViewMain::show_view()
         return;
     }
 
-    // もしarticleクラスがまだキャッシュにあるdatを解析していないときに
-    // drawarea()->append_res()を呼ぶと update_finish() がコールバック
-    // されて2回再描画することになるので、 show_view() の中で update_finish()を
-    // 呼ばないようにする。動作をまとめると次のようになる。
+    // 負荷を減らすため update_view() や update_finish() が呼び出されるまで描画不可にしておく
+    drawarea()->set_enable_draw( false );
 
+    // articleクラスがまだキャッシュにあるdatを解析していないときに
+    // drawarea()->append_res()を呼ぶと、 nodetree が作られて update_finish() が
+    // コールバックされるので、 キャッシュをまだ読み込んでない時は show_view() の中で
+    // update_finish()を呼ばないようにする。動作をまとめると次のようになる。
+    //
     // オフライン　かつ
     //   キャッシュを読み込んでいない場合  -> articleでnodetreeが作られた時に update_finish がコールバックされる
     //   キャッシュを読み込んでいる場合    -> show_viewから直接  update_finish を呼ぶ
@@ -360,7 +411,13 @@ void ArticleViewMain::update_view()
 
     if( num_from > num_to ) return;
 
+#ifdef _DEBUG
+    std::cout << "append " << num_from << " to " << num_to << std::endl;
+#endif
+
     drawarea()->append_res( num_from, num_to );
+
+    drawarea()->set_enable_draw( true );
     drawarea()->redraw_view();
 }
 
@@ -387,7 +444,6 @@ void ArticleViewMain::update_finish()
     // タブのアイコン状態を更新
     ARTICLE::get_admin()->set_command( "toggle_icon", get_url() );
 
-
 #ifdef _DEBUG
     const int code = DBTREE::article_code( url_article() );
     std::cout << "ArticleViewMain::update_finish " << str_label << " code = " << code << std::endl;;
@@ -399,30 +455,37 @@ void ArticleViewMain::update_finish()
     if( ! number_new ) drawarea()->hide_separator_new();
 
     // ステータス更新 (実況中はフォーカスされてなくても表示)
+    std::string force;
+    if( get_live() ) force = "force";
     create_status_message();
-    ARTICLE::get_admin()->set_command( "set_status", get_url(), get_status(), ( get_live() ? "force" : "" ) );
+    ARTICLE::get_admin()->set_command( "set_status", get_url(), get_status(), force );
+    ARTICLE::get_admin()->set_command( "set_status_color", get_url(), get_color(), force );
 
     // タイトルセット
     set_title( DBTREE::article_subject( url_article() ) );
     ARTICLE::get_admin()->set_command( "set_title", get_url(), get_title() );
 
-    // 全体再描画
-    drawarea()->redraw_view();
+    drawarea()->set_enable_draw( true );
+
+    // ロード中に goto_num() が明示的に呼び出された場合はgoto_num()を呼びつづける
+    if( m_gotonum_reserve_to ){
+#ifdef _DEBUG
+        std::cout << "reserve\n";
+#endif
+        goto_num( m_gotonum_reserve_to, m_gotonum_reserve_from );
+    }
 
     // 前回見ていた所にジャンプ
-    if( m_gotonum_seen && number_load >= m_gotonum_seen ){
+    else if( m_gotonum_seen && number_load >= m_gotonum_seen ){
 #ifdef _DEBUG
         std::cout << "goto_seen\n";
 #endif
-        ArticleViewBase::goto_num( m_gotonum_seen );
+        ArticleViewBase::goto_num( m_gotonum_seen, 0 );
         m_gotonum_seen = 0;
     }
 
-    // ロード中に goto_num() が明示的に呼び出された場合はgoto_num()を呼びつづける
-    if( m_gotonum_reserve ) goto_num( m_gotonum_reserve );
-
     // ロード後に末尾ジャンプ
-    else if( CONFIG::get_jump_after_reload() && number_new ){
+    else if( ! get_live() && CONFIG::get_jump_after_reload() && number_new ){
 #ifdef _DEBUG
         std::cout << "jump_after_reload\n";
 #endif
@@ -430,13 +493,21 @@ void ArticleViewMain::update_finish()
     }
 
     // ロード後に新着へジャンプ
-    else if( CONFIG::get_jump_new_after_reload() && number_new ){
+    else if( ! get_live() && CONFIG::get_jump_new_after_reload() && number_new ){
 #ifdef _DEBUG
         std::cout << "jump_new_after_reload\n";
 #endif
         goto_new();
     }
 
+    // 全体再描画
+    else{
+#ifdef _DEBUG
+        std::cout << "redraw\n";
+#endif
+        drawarea()->redraw_view();
+    }
+
     // 実況モードで新着がない場合はリロード間隔を空ける
     if( get_live() ){
 
@@ -462,7 +533,7 @@ void ArticleViewMain::update_finish()
             set_autoreload_sec( MAX( live_sec, get_autoreload_sec() - LIVE_SEC_PLUS ) );
 
             // messageビューが出ているときはフォーカスを移す
-            CORE::core_set_command( "switch_message" );
+            if( ! MESSAGE::get_admin()->empty() ) CORE::core_set_command( "switch_message" );
         }
 
         drawarea()->update_live_speed( get_autoreload_sec() );
@@ -502,7 +573,9 @@ void ArticleViewMain::create_status_message()
            << " [ 全 " << number_load
            << " / 新着 " << number_new;
 
-    if( DBTREE::article_write_time( url_article() ) ) ss_tmp << " / 最終書込 " << DBTREE::article_write_date( url_article() );
+    const time_t wtime = DBTREE::article_write_time( url_article() );
+    if( wtime ) ss_tmp << " / 最終書込 "
+                       << ( MISC::timettostr( wtime, MISC::TIME_WEEK ) + " ( " +  MISC::timettostr( wtime, MISC::TIME_PASSED ) +  " )" );
 
     std::string str_stat;
     if( is_old() ) str_stat = "[ DAT落ち 又は 移転しました ] ";
