@@ -4,6 +4,7 @@
 #include "jddebug.h"
 
 #include "bbslistadmin.h"
+#include "bbslistviewbase.h"
 #include "toolbar.h"
 
 #include "skeleton/view.h"
@@ -78,26 +79,44 @@ BBSListAdmin::~BBSListAdmin()
 
     if( m_toolbar ) delete m_toolbar;
     BBSLIST::delete_undo_buffer_favorite();
+}
+
+
+void BBSListAdmin::save_session()
+{
+    Admin::save_session();
 
     // bbslistのページの位置保存
     SESSION::set_bbslist_page( get_current_page() );
 }
 
 
-
 // 前回開いていたURLを復元
 void BBSListAdmin::restore( const bool only_locked )
 {
     COMMAND_ARGS command_arg;
 
-    // bbslist
+    // 板一覧
+    // 初回起動時は板一覧の読み込みもここで行われる
     command_arg = url_to_openarg( URL_BBSLISTVIEW, true, false );
     open_view( command_arg );
 
-    // favorite
+    // お気に入り
     command_arg = url_to_openarg( URL_FAVORITEVIEW, true, false );
     open_view( command_arg );
 
+    // スレ履歴
+    command_arg = url_to_openarg( URL_HISTTHREADVIEW, true, false );
+    open_view( command_arg );
+
+    // 板履歴
+    command_arg = url_to_openarg( URL_HISTBOARDVIEW, true, false );
+    open_view( command_arg );
+
+    // 最近閉じたスレ
+    command_arg = url_to_openarg( URL_HISTCLOSEVIEW, true, false );
+    open_view( command_arg );
+
     set_command( "set_page", std::string(), MISC::itostr( SESSION::bbslist_page() ) );
     set_command( "hide_tabs" );
 }
@@ -131,7 +150,7 @@ void BBSListAdmin::show_toolbar()
         m_toolbar = new BBSListToolBar();
         get_notebook()->append_toolbar( *m_toolbar );
 
-        if( SESSION::get_show_bbslist_toolbar() ) m_toolbar->show_toolbar();
+        if( SESSION::get_show_bbslist_toolbar() ) m_toolbar->open_buttonbar();
     }
 
     get_notebook()->show_toolbar();
@@ -139,21 +158,29 @@ void BBSListAdmin::show_toolbar()
 
 
 //
-// ツールバー表示切り替え
+// ツールバー表示/非表示切り替え
 //
 void BBSListAdmin::toggle_toolbar()
 {
     if( ! m_toolbar ) return;
 
-    if( SESSION::get_show_bbslist_toolbar() ) m_toolbar->show_toolbar();
-    else m_toolbar->hide_toolbar();
+    if( SESSION::get_show_bbslist_toolbar() ){
+        m_toolbar->open_buttonbar();
+        m_toolbar->show_toolbar();
+    }
+    else m_toolbar->close_buttonbar();
 }
 
 
 SKELETON::View* BBSListAdmin::create_view( const COMMAND_ARGS& command )
 {
-    int type = CORE::VIEW_BBSLISTVIEW;
+    int type = CORE::VIEW_NONE;
+
+    if( command.url == URL_BBSLISTVIEW ) type = CORE::VIEW_BBSLISTVIEW;
     if( command.url == URL_FAVORITEVIEW ) type = CORE::VIEW_FAVORITELIST;
+    if( command.url == URL_HISTTHREADVIEW ) type = CORE::VIEW_HISTTHREAD;
+    if( command.url == URL_HISTCLOSEVIEW ) type = CORE::VIEW_HISTCLOSE;
+    if( command.url == URL_HISTBOARDVIEW ) type = CORE::VIEW_HISTBOARD;
 
     CORE::VIEWFACTORY_ARGS view_args;
     view_args.arg1 = command.arg4;
@@ -174,14 +201,22 @@ void BBSListAdmin::command_local( const COMMAND_ARGS& command )
     if( view ){
 
         // アイテム追加
-        // append_favorite を呼ぶ前に共有バッファにコピーデータをセットしておくこと
+        // 共有バッファにコピーデータをセットしておくこと
         if( command.command  == "append_item" ) view->set_command( "append_item" );
 
-        // アイテム削除
-        if( command.command  == "remove_item" ) view->set_command( "remove_item", command.arg1 );
+        // 履歴のセット
+        // 先頭にアイテムを追加する。ツリーにアイテムが含まれている場合は移動する
+        // 共有バッファにコピーデータをセットしておくこと
+        else if( command.command  == "append_history" ) view->set_command( "append_history" );
+
+        // 項目削除
+        else if( command.command  == "remove_item" ) view->set_command( "remove_item", command.arg1 );
+
+        // 全項目削除
+        else if( command.command  == "remove_allitems" ) view->set_command( "remove_allitems" );
 
         // ツリーの編集
-        if( command.command  == "edit_tree" ) view->set_command( "edit_tree" );
+        else if( command.command  == "edit_tree" ) view->set_command( "edit_tree" );
 
         // お気に入りルート更新チェック
         else if( command.command  == "check_update_root" ) view->set_command( "check_update_root" );
@@ -193,15 +228,58 @@ void BBSListAdmin::command_local( const COMMAND_ARGS& command )
 
         // XML保存
         else if( command.command  == "save_xml" ) view->set_command( "save_xml" );
+
+        // スレのアイコン表示を更新
+        else if( command.command  == "toggle_articleicon" ) view->set_command( "toggle_articleicon", command.arg1 );
+
+        // 板のアイコン表示を更新
+        else if( command.command  == "toggle_boardicon" ) view->set_command( "toggle_boardicon", command.arg1 );
     }
+
+    // ポップアップを隠す(インスタンスは削除しない)
+    else if( command.command == "hide_popup" ) hide_popup();
 }
 
 
-//
-// (お気に入りの)アイコン表示切り替え
-//
-void BBSListAdmin::toggle_icon( const std::string& url )
+// 履歴を DATA_INFO_LIST 型で取得
+void BBSListAdmin::get_history( const std::string& url, CORE::DATA_INFO_LIST& info_list )
 {
-    SKELETON::View* view = get_view( URL_FAVORITEVIEW );
-    if( view ) view->set_command( "toggle_icon", url );
+    info_list.clear();
+
+    BBSListViewBase* view = dynamic_cast< BBSListViewBase* >( get_view( url ) );
+    if( view ) return view->get_history( info_list );
+}
+
+
+// サイドバーの指定したidのディレクトリに含まれるスレのアドレスを取得
+void BBSListAdmin::get_threads( const std::string& url, const int dirid, std::vector< std::string >& list_url )
+{
+    list_url.clear();
+
+    BBSListViewBase* view = dynamic_cast< BBSListViewBase* >( get_view( url ) );
+    if( view ) view->get_threads( dirid, list_url );
+}
+
+
+// サイドバーの指定したidのディレクトリの名前を取得
+const std::string BBSListAdmin::get_dirname( const std::string& url, const int dirid )
+{
+    BBSListViewBase* view = dynamic_cast< BBSListViewBase* >( get_view( url ) );
+    if( view ) return view->get_dirname( dirid );
+
+    return std::string();
+}
+
+
+//
+// カレントビューでポップアップ表示していたら隠す(インスタンスは削除しない)
+//
+void BBSListAdmin::hide_popup()
+{
+#ifdef _DEBUG
+    std::cout << "BBSListAdmin::hide_popup\n";
+#endif
+
+    SKELETON::View* view = get_current_view();
+    if( view ) view->set_command( "hide_popup" );
 }
