@@ -5,36 +5,18 @@
 #ifndef _BOARDCOLUMNS_H
 #define _BOARDCOLUMNS_H
 
+#include "boardcolumnsid.h"
+
 #include <gtkmm.h>
+#include <ctime>
+
+namespace DBTREE
+{
+    class ArticleBase;
+}
 
 namespace BOARD
 {
-    // 列ID
-    enum
-    {
-        COL_MARK = 0,
-        COL_ID,
-        COL_SUBJECT,
-        COL_RES,
-        COL_STR_LOAD,
-        COL_STR_NEW,
-        COL_SINCE,
-        COL_WRITE,
-        COL_SPEED,
-            
-        // 以下は不可視
-        COL_MARK_VAL,
-        COL_DRAWBG,
-        COL_LOAD,
-        COL_NEW,
-        COL_SINCE_T,
-        COL_WRITE_T,
-        COL_ID_DAT,
-            
-        COL_NUM_COL
-    };
-
-
     // 列
     class TreeColumns : public Gtk::TreeModel::ColumnRecord
     {
@@ -49,14 +31,15 @@ namespace BOARD
         Gtk::TreeModelColumn< Glib::ustring > m_col_since;
         Gtk::TreeModelColumn< Glib::ustring > m_col_write;
         Gtk::TreeModelColumn< int > m_col_speed;
-        
-        Gtk::TreeModelColumn< int > m_col_mark_val;  // マークの優先順(新着を一番上にする)
+        Gtk::TreeModelColumn< int > m_col_diff;
+        Gtk::TreeModelColumn< Glib::ustring > m_col_board;
+
+        // 以下は不可視
+        Gtk::TreeModelColumn< int > m_col_mark_val;
         Gtk::TreeModelColumn< bool > m_col_drawbg; // true なら背景を塗る
-        Gtk::TreeModelColumn< int > m_col_load;        
         Gtk::TreeModelColumn< int > m_col_new;
-        Gtk::TreeModelColumn< time_t > m_col_since_t;
         Gtk::TreeModelColumn< time_t > m_col_write_t;
-        Gtk::TreeModelColumn< Glib::ustring > m_col_id_dat;
+        Gtk::TreeModelColumn< DBTREE::ArticleBase* > m_col_article;
         
         TreeColumns(){
             
@@ -69,14 +52,14 @@ namespace BOARD
             add( m_col_since );
             add( m_col_write );
             add( m_col_speed );
+            add( m_col_diff );
+            add( m_col_board );
 
             add( m_col_mark_val );
             add( m_col_drawbg );
-            add( m_col_load );            
             add( m_col_new );
-            add( m_col_since_t );
             add( m_col_write_t );
-            add( m_col_id_dat );
+            add( m_col_article );
         }
 
         ~TreeColumns(){}
