@@ -25,7 +25,12 @@
 #include <dirent.h>
 
 #include <fcntl.h>
+#include <cstring>
 
+enum
+{
+    MAX_SAFE_PATH = 1024
+};
 
 std::string root_path;
 
@@ -36,11 +41,16 @@ std::string CACHE::path_conf()
     return CACHE::path_root() + "jd.conf";
 }
 
+std::string CACHE::path_conf_bkup()
+{
+    return CACHE::path_conf() + ".bkup";
+}
+
 
 // 旧設定ファイル
 std::string CACHE::path_conf_old()
 {
-    std::string home = getenv( "HOME" );
+    std::string home = MISC::getenv_limited( ENV_HOME, MAX_SAFE_PATH );
 
     return home + "/.jdrc";
 }
@@ -53,16 +63,12 @@ std::string CACHE::path_session()
 }
 
 
-// ディストリ判別用ファイル
-std::string CACHE::path_issue_net()
-{
-    return "/etc/issue.net";
-}
-
-
 // ロックファイル
 std::string CACHE::path_lock()
 {
+    const std::string jd_lock = MISC::getenv_limited( "JD_LOCK", MAX_SAFE_PATH );
+    if( ! jd_lock.empty() ) return jd_lock;
+
     return CACHE::path_root() + "JDLOCK";
 }
 
@@ -79,13 +85,13 @@ std::string CACHE::path_root()
 {
     if( root_path.empty() ){
 
-        if( getenv( "JD_CACHE" ) ) root_path = getenv( "JD_CACHE" );
-        else root_path = "~/.jd/";
+        const std::string jd_cache = MISC::getenv_limited( "JD_CACHE", MAX_SAFE_PATH );
+        root_path = jd_cache.empty() ? "~/.jd/" : jd_cache;
 
         if( root_path[ root_path.length() -1 ] != '/' ) root_path = root_path + "/";
 
         if( root_path[ 0 ] == '~' ){
-            std::string home = getenv( "HOME" );
+            std::string home = MISC::getenv_limited( ENV_HOME , MAX_SAFE_PATH );
             root_path.replace( 0, 1, home );
         }
     }
@@ -137,11 +143,22 @@ std::string CACHE::path_etcboard()
 
 // ユーザーコマンド設定ファイル
 std::string CACHE::path_usrcmd()
+{
+    return CACHE::path_root() +  "usrcmd.xml";
+}
+
+std::string CACHE::path_usrcmd_old()
 {
     return CACHE::path_root() +  "usrcmd.txt";
 }
 
 
+// リンクフィルタ設定ファイル
+std::string CACHE::path_linkfilter()
+{
+    return CACHE::path_root() +  "linkfilter.xml";
+}
+
 
 // 履歴
 std::string CACHE::path_xml_history()
@@ -179,6 +196,13 @@ std::string CACHE::path_xml_history_close_old()
 }
 
 
+// View履歴
+std::string CACHE::path_xml_history_view()
+{
+    return CACHE::path_root() +  "hist_view.xml";
+}
+
+
 // 板移転情報
 std::string CACHE::path_movetable()
 {
@@ -277,6 +301,9 @@ std::string CACHE::path_article_ext_info( const std::string& url, const std::str
 
 std::string CACHE::path_dat( const std::string& url )
 {
+    // file:// の場合
+    if( url.c_str()[ 0 ] == 'f' && url.c_str()[ 1 ] == 'i' ) return url.substr( strlen( "file://" ) );
+
     return CACHE::path_board_root( url ) + DBTREE::article_id( url );
 }
 
@@ -327,12 +354,30 @@ std::string CACHE::path_img_abone_root()
 }
 
 
+//
+// ログのルートパス
+//
+std::string CACHE::path_logroot()
+{
+    return CACHE::path_root() + "log/";
+}
+
+
 //
 // 書き込みログ
 //
 std::string CACHE::path_postlog()
 {
-    return CACHE::path_root() +  "post.log";
+    return path_logroot() + "postlog";
+}
+
+
+//
+// メッセージログ（-lオプション）
+//
+std::string CACHE::path_msglog()
+{
+    return path_logroot() + "msglog";
 }
 
 
@@ -345,6 +390,14 @@ std::string CACHE::path_completion( int mode )
 }
 
 
+//
+// サウンドファイルのルートパス
+//
+std::string CACHE::path_sound_root()
+{
+    return CACHE::path_root() + "sound/";
+}
+
 
 //
 // 画像キャッシュファイルの名前
@@ -582,14 +635,28 @@ bool CACHE::mkdir_boardroot( const std::string& url )
 }
 
 
+//
+// ログのルートディレクトリをmkdir
+//
+bool CACHE::mkdir_logroot()
+{
+    // root
+    std::string path_logroot = CACHE::path_logroot();
+    if( ! CACHE::jdmkdir( path_logroot ) ){
+        MISC::ERRMSG( "can't create " + path_logroot );
+        return false;
+    }
+
+    return true;
+}
 
 
 size_t CACHE::load_rawdata( const std::string& path, std::string& str )
 {
     str.clear();
-    
     std::ifstream fin;
-    fin.open( path.c_str() );
+
+    fin.open( to_locale_cstr( path ) );
     if( !fin.is_open() ) return 0;
     getline( fin, str, '\0' );
     fin.close();
@@ -598,11 +665,12 @@ size_t CACHE::load_rawdata( const std::string& path, std::string& str )
 }
 
 
-size_t CACHE::load_rawdata( const std::string& path, char* data, size_t n )
+size_t CACHE::load_rawdata( const std::string& path, char* data, const size_t n )
 {
     size_t count = 0;
     std::ifstream fin;
-    fin.open( path.c_str() );
+
+    fin.open( to_locale_cstr( path ), std::ios::binary );
     if( !fin.is_open() ) return 0;
     fin.read( data, n );
     count = fin.gcount();
@@ -612,20 +680,23 @@ size_t CACHE::load_rawdata( const std::string& path, char* data, size_t n )
 }
 
 
-size_t CACHE::save_rawdata( const std::string& path, const std::string& str, bool append )
+size_t CACHE::save_rawdata( const std::string& path, const std::string& str, const bool append )
 {
     return save_rawdata( path, str.c_str(), str.length(), append );
 }
 
 
-
-size_t CACHE::save_rawdata( const std::string& path, const char* data, size_t n, bool append )
+size_t CACHE::save_rawdata( const std::string& path, const char* data, size_t n, const bool append )
 {
     size_t count = 0;
     size_t byte = 0;
     std::ofstream fout;
-    if( append ) fout.open( path.c_str(), std::ios::app );
-    else fout.open( path.c_str() );
+    std::ofstream::openmode fmode;
+    
+    if( append ) fmode = std::ios::app | std::ios::ate | std::ios::binary;
+    else fmode = std::ios::binary;
+    
+    fout.open( to_locale_cstr( path ), fmode );
     if( !fout.is_open() ){
         MISC::ERRMSG( "can't open " + path );
         return 0;
@@ -660,10 +731,21 @@ const int CACHE::file_exists( const std::string& path )
     struct stat buf_stat;
 
     if( path.empty() ) return EXIST_ERROR;
-    if( stat( path.c_str(), &buf_stat ) != 0 ) return EXIST_ERROR;
+
+    std::string path_s = path;
+#ifdef _WIN32
+    // on windows fail stat() directory path with ends '/'
+    // "c:/" = ok, "c:" = fail
+    // "c:/dir/" = fail, "c:/dir" = ok
+    if( path.length() > 3 && path[ path.length() - 1 ] == '/' ){
+        path_s = path.substr( 0, path.length() - 1 );
+    }
+#endif
+    if( stat( to_locale_cstr( path_s ), &buf_stat ) != 0 ) return EXIST_ERROR;
 
     if( S_ISREG( buf_stat.st_mode ) ) return EXIST_FILE;
     if( S_ISDIR( buf_stat.st_mode ) ) return EXIST_DIR;
+    if( S_ISFIFO( buf_stat.st_mode ) ) return EXIST_FIFO;
 
     return EXIST;
 }
@@ -673,7 +755,7 @@ size_t CACHE::get_filesize( const std::string& path )
 {
     struct stat buf_stat;
 
-    if( stat( path.c_str(), &buf_stat ) != 0 ) return 0;
+    if( stat( to_locale_cstr( path ), &buf_stat ) != 0 ) return 0;
     if( S_ISREG( buf_stat.st_mode ) ) return buf_stat.st_size;
     return 0;
 }
@@ -683,7 +765,7 @@ time_t CACHE::get_filemtime( const std::string& path )
 {
     struct stat buf_stat;
 
-    if( stat( path.c_str(), &buf_stat ) != 0 ) return 0;
+    if( stat( to_locale_cstr( path ), &buf_stat ) != 0 ) return 0;
     if( S_ISREG( buf_stat.st_mode ) ) return buf_stat.st_mtime;
     return 0;
 }
@@ -704,13 +786,18 @@ bool CACHE::jdmkdir( const std::string& path )
     
     if( path.find( "~/" ) == 0 ){
 
-        std::string homedir = getenv( "HOME" );
+        std::string homedir = MISC::getenv_limited( ENV_HOME, MAX_SAFE_PATH );
         if( homedir.empty() ) return false;
 
         target = homedir + path.substr( 2 );
     }
 
+#ifdef _WIN32
+    // on windows has case of start drive letter "c:/...", or UNC "//pcname/..."
+    if( target[ 0 ] != '/' && target[ 1 ] != ':' ) return false;
+#else
     if( target[ 0 ] != '/' ) return false;
+#endif
     if( target[ target.length() -1 ] != '/' ) target += "/";
 
 #ifdef _DEBUG
@@ -731,7 +818,11 @@ bool CACHE::jdmkdir( const std::string& path )
         
         if( CACHE::file_exists( currentdir ) == EXIST_DIR ) continue;
 
-        if( mkdir( currentdir.c_str(), 0755 ) != 0 ){
+#ifdef _WIN32
+        if( mkdir( to_locale_cstr( currentdir ) ) != 0 ){
+#else
+        if( mkdir( to_locale_cstr( currentdir ), 0755 ) != 0 ){
+#endif
             MISC::ERRMSG( "mkdir failed " + currentdir );
             return false;
         }
@@ -748,7 +839,7 @@ bool CACHE::jdmkdir( const std::string& path )
 bool CACHE::jdcopy( const std::string& file_from, const std::string& file_to )
 {
     struct stat buf_stat;
-    if( stat( file_from.c_str(), &buf_stat ) != 0 ) return false;
+    if( stat( to_locale_cstr( file_from ), &buf_stat ) != 0 ) return false;
 
 #ifdef _DEBUG
     std::cout << "CACHE::jdcopy : from = " << file_from << std::endl;
@@ -786,7 +877,7 @@ bool CACHE::jdcopy( const std::string& file_from, const std::string& file_to )
 bool CACHE::jdmv( const std::string& file_from, const std::string& file_to )
 {
     if( CACHE::jdcopy( file_from, file_to ) ){
-        unlink( file_from.c_str() );
+        unlink( to_locale_cstr( file_from ) );
         return true;
     }
 
@@ -822,7 +913,7 @@ std::string CACHE::copy_file( Gtk::Window* parent, const std::string& file_from,
 
     if( CACHE::jdcopy( file_from, path_to ) ) return path_to;
     else{
-        SKELETON::MsgDiag mdiag( parent, file_to + "\n\nの保存に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。" );
+        SKELETON::MsgDiag mdiag( parent, path_to + "\n\nの保存に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。" );
         mdiag.run();
     }
 
@@ -863,15 +954,17 @@ void CACHE::add_filter_to_diag( Gtk::FileChooserDialog& diag, const int type )
 //
 // parent == NULL の時はメインウィンドウをparentにする
 // open_path はデフォルトの参照先
-// 戻り値は選択されたファイルのpath
+// multi == true なら複数選択可能
+// 戻り値は選択されたファイルのpathのリスト
 //
-std::string CACHE::open_load_diag( Gtk::Window* parent, const std::string& open_path, const int type )
+const std::list< std::string > CACHE::open_load_diag( Gtk::Window* parent, const std::string& open_path, const int type, const bool multi )
 {
     std::string dir = MISC::get_dir( open_path );
-    if( dir.empty() ) dir = getenv( "HOME" );
+    if( dir.empty() ) dir = MISC::getenv_limited( ENV_HOME, MAX_SAFE_PATH );
 
     SKELETON::FileDiag diag( parent, "ファイルを開く", Gtk::FILE_CHOOSER_ACTION_OPEN );
 
+    diag.set_select_multiple( multi );
     diag.set_current_folder( dir );
     add_filter_to_diag( diag, type );
 
@@ -879,10 +972,10 @@ std::string CACHE::open_load_diag( Gtk::Window* parent, const std::string& open_
     {
         diag.hide();
 
-        return diag.get_filename();
+        return MISC::recover_path( diag.get_filenames() );
     }
 
-    return std::string();
+    return std::list< std::string >();
 }
 
 
@@ -904,8 +997,8 @@ std::string CACHE::open_save_diag( Gtk::Window* parent, const std::string& dir,
     SKELETON::FileDiag diag( parent, "保存先選択", Gtk::FILE_CHOOSER_ACTION_SAVE );
     if( dir.empty() )
     {
-        const char* home = getenv( "HOME" );
-        if( home ) diag.set_current_folder( home );
+        const std::string home = MISC::getenv_limited( ENV_HOME, MAX_SAFE_PATH );
+        if( ! home.empty() ) diag.set_current_folder( home );
     }
     else
     {
@@ -916,8 +1009,8 @@ std::string CACHE::open_save_diag( Gtk::Window* parent, const std::string& dir,
 
     if( diag.run() != Gtk::RESPONSE_ACCEPT ) return std::string();
     diag.hide();
-        
-    std::string path_to = diag.get_filename();
+
+    std::string path_to = MISC::recover_path( diag.get_filename() );
 
 #ifdef _DEBUG
     std::cout << "to   = " << path_to  << std::endl;
@@ -956,7 +1049,7 @@ std::list< std::string > CACHE::get_filelist( const std::string& dir )
     std::cout << "CACHE::get_filelist " << dir << std::endl;
 #endif
 
-    DIR *dirp = opendir( dir.c_str() );
+    DIR *dirp = opendir( to_locale_cstr( dir ) );
     if( !dirp ) return list_files;
 
     struct dirent *direntry;
@@ -982,15 +1075,15 @@ std::list< std::string > CACHE::get_filelist( const std::string& dir )
 //
 // dir ディレクトリ内のレギュラーファイルの合計サイズを取得
 //
-int64_t CACHE::get_dirsize( const std::string& dir )
+guint64 CACHE::get_dirsize( const std::string& dir )
 {
-    int64_t total_size = 0;
+    guint64 total_size = 0;
 
 #ifdef _DEBUG
     std::cout << "CACHE::get_dirsize " << dir << std::endl;
 #endif
 
-    DIR *dirp = opendir( dir.c_str() );
+    DIR *dirp = opendir( to_locale_cstr( dir ) );
     if( !dirp ) return 0;
 
     struct dirent *direntry;
@@ -1007,3 +1100,34 @@ int64_t CACHE::get_dirsize( const std::string& dir )
 
     return total_size;
 }
+
+
+// 相対パスから絶対パスを取得してファイルが存在すれば絶対パスを返す
+// ファイルが存在しない場合は std::string() を返す
+const std::string CACHE::get_realpath( const std::string& path )
+{
+    std::string path_real;
+
+    char resolved_path[ PATH_MAX + 1 ];
+#ifdef _WIN32
+    // _fullpath() are not checked　the path is completely available
+    char* ret = _fullpath( resolved_path, to_locale_cstr( path ), PATH_MAX );
+#else
+    char* ret = realpath( to_locale_cstr( path ), resolved_path );
+#endif
+    if( ret ){
+        path_real = ret;
+    }
+    else return std::string();
+
+    if( CACHE::file_exists( path_real ) == EXIST_ERROR ){
+        return std::string();
+    }
+
+#ifdef _DEBUG
+    std::cout << "CACHE::get_realpath path = " << path
+              << " real = " << path_real << std::endl;
+#endif
+
+    return path_real;
+}
