@@ -94,10 +94,26 @@ void CONFIG::set_use_tree_gtkrc( const bool use ){ get_confitem()->use_tree_gtkr
 const bool CONFIG::get_use_select_gtkrc(){ return get_confitem()->use_select_gtkrc; }
 void CONFIG::set_use_select_gtkrc( const bool use ){ get_confitem()->use_select_gtkrc = use; }
 
+// ツリービューの行間スペース
 const int CONFIG::get_tree_ypad(){ return get_confitem()->tree_ypad; }
 
+// ツリービューにエクスパンダを表示
+const bool CONFIG::get_tree_show_expanders(){ return get_confitem()->tree_show_expanders; }
+
+// ツリービューのレベルインデント調整量(ピクセル)
+const int CONFIG::get_tree_level_indent(){ return get_confitem()->tree_level_indent; }
+
+// カテゴリを開いたときにツリービューをスクロールする
+const bool CONFIG::get_scroll_tree(){ return get_confitem()->scroll_tree; }
+
 const int CONFIG::get_view_margin(){ return get_confitem()->view_margin; }
 
+// スクロールバーを左に配置
+const bool CONFIG::get_left_scrbar(){ return get_confitem()->left_scrbar; }
+
+// スレ一覧で古いスレも表示 	 
+const bool CONFIG::get_show_oldarticle(){ return get_confitem()->show_oldarticle; }
+
 // フォント
 const std::string& CONFIG::get_fontname( const int id )
 {
@@ -171,6 +187,8 @@ void CONFIG::set_proxy_for_data( const std::string& proxy ){ get_confitem()->set
 void CONFIG::set_proxy_port_for_data( int port ){ get_confitem()->proxy_port_for_data = port; }
 
 const int CONFIG::get_loader_bufsize(){ return get_confitem()->loader_bufsize; }
+const int CONFIG::get_loader_bufsize_board(){ return get_confitem()->loader_bufsize_board; }
+
 const int CONFIG::get_loader_timeout(){ return get_confitem()->loader_timeout; }
 const int CONFIG::get_loader_timeout_post(){ return get_confitem()->loader_timeout_post; }
 const int CONFIG::get_loader_timeout_data(){ return get_confitem()->loader_timeout_img; } // 旧 get_loader_timeout_img() 関数
@@ -179,6 +197,9 @@ const int CONFIG::get_loader_timeout_checkupdate(){ return get_confitem()->loade
 const bool CONFIG::get_use_ipv6(){ return get_confitem()->use_ipv6; }
 void CONFIG::set_use_ipv6( const bool set ){ get_confitem()->use_ipv6 = set; }
 
+// 同一ホストに対する最大コネクション数( 1 または 2 )
+const int CONFIG::get_connection_num(){ return get_confitem()->connection_num; }
+
 const std::string& CONFIG::get_command_openurl() { return get_confitem()->command_openurl; }
 void CONFIG::set_command_openurl( const std::string& command ){ get_confitem()->command_openurl = command; }
 
@@ -208,6 +229,14 @@ void CONFIG::set_use_inline_image( const bool inline_img ){ get_confitem()->use_
 const bool CONFIG::get_show_ssspicon(){ return get_confitem()->show_ssspicon; }
 void CONFIG::set_show_sssp_icon( const bool show ){ get_confitem()->show_ssspicon = show; }
 
+// インライン画像の最大幅と高さ
+const int CONFIG::get_embimg_width(){ return get_confitem()->embimg_width; }
+const int CONFIG::get_embimg_height(){ return get_confitem()->embimg_height; }
+
+// 画像ビューでdeleteを押したときに確認ダイアログを表示する
+const bool CONFIG::get_show_delimgdiag(){ return get_confitem()->show_delimgdiag; }
+void CONFIG::set_show_delimgdiag( const bool show ){ get_confitem()->show_delimgdiag = show; }
+
 const bool CONFIG::get_use_mosaic(){ return get_confitem()->use_mosaic; }
 void CONFIG::set_use_mosaic( const bool mosaic ) { get_confitem()->use_mosaic = mosaic; }
 const int CONFIG::get_mosaic_size(){ return get_confitem()->mosaic_size; }
@@ -221,9 +250,6 @@ const int CONFIG::get_max_img_size(){ return get_confitem()->max_img_size; }
 const int CONFIG::get_max_img_pixel(){ return get_confitem()->max_img_pixel; }
 const int CONFIG::get_imgcache_size(){ return get_confitem()->imgcache_size; }
 
-const bool CONFIG::get_show_oldarticle(){ return get_confitem()->show_oldarticle; }
-void CONFIG::set_show_oldarticle( const bool showarticle ){ get_confitem()->show_oldarticle = showarticle; }
-
 const int CONFIG::get_newthread_hour(){ return get_confitem()->newthread_hour; }
 
 const bool CONFIG::get_inc_search_board(){ return get_confitem()->inc_search_board; }
@@ -231,6 +257,12 @@ const bool CONFIG::get_inc_search_board(){ return get_confitem()->inc_search_boa
 const bool CONFIG::get_show_deldiag(){ return get_confitem()->show_deldiag; }
 void CONFIG::set_show_deldiag( const bool show ){ get_confitem()->show_deldiag = show; }
 
+// スレ一覧をロードする前にキャッシュにある一覧を表示
+const bool CONFIG::get_show_cached_board(){ return get_confitem()->show_cached_board; }
+
+// スレ一覧でお知らせスレ(924)のアイコンを表示する
+const bool CONFIG::get_show_924(){ return get_confitem()->show_924; }
+
 const int CONFIG::get_tree_scroll_size(){ return get_confitem()->tree_scroll_size; }
 const int CONFIG::get_scroll_size(){ return get_confitem()->scroll_size; }
 const int CONFIG::get_key_scroll_size(){ return get_confitem()->key_scroll_size; }
@@ -262,15 +294,41 @@ const bool CONFIG::get_save_post_history(){ return get_confitem()->save_posthist
 void CONFIG::set_save_post_history( const bool save ){ get_confitem()->save_posthist = save; }
 
 const bool CONFIG::get_hide_writing_dialog(){ return get_confitem()->hide_writing_dialog; }
+
+// 編集中のメッセージの保存確認ダイアログを表示する
+const bool CONFIG::get_show_savemsgdiag(){ return get_confitem()->show_savemsgdiag; }
+void CONFIG::set_show_savemsgdiag( const bool show ){ get_confitem()->show_savemsgdiag = show; }
+
+// 書き込みビューでテキストを折り返す
+const bool CONFIG::get_message_wrap(){ return get_confitem()->message_wrap; }
+void CONFIG::set_message_wrap( const bool wrap ){ get_confitem()->message_wrap = wrap; }
+
 const bool CONFIG::get_fold_message(){ return get_confitem()->fold_message; }
 void CONFIG::set_fold_message( const bool fold ){ get_confitem()->fold_message = fold; }
 
+const bool CONFIG::get_fold_image(){ return get_confitem()->fold_image; }
+
+const bool CONFIG::get_keep_im_status(){ return get_confitem()->keep_im_status; }
+
 const int CONFIG::get_margin_popup(){ return get_confitem()->margin_popup; }
 void CONFIG::set_margin_popup( const int margin ){ get_confitem()->margin_popup = margin; }
 
+// 画像ポップアップとカーソルの間のマージン
+const int CONFIG::get_margin_imgpopup_x(){ return get_confitem()->margin_imgpopup_x; }
 const int CONFIG::get_margin_imgpopup(){ return get_confitem()->margin_imgpopup; }
 
+// ポップアップが消えるまでの時間(ミリ秒)
+const int CONFIG::get_hide_popup_msec(){ return get_confitem()->hide_popup_msec; }
+
+// マウスジェスチャを有効
+const bool CONFIG::get_enable_mg(){ return get_confitem()->enable_mg; }
+
+// マウスジェスチャの判定開始半径
 const int CONFIG::get_mouse_radius(){ return get_confitem()->mouse_radius; }
+
+// 数字入力ジャンプのウェイト(ミリ秒)
+const int CONFIG::get_numberjmp_msec(){ return get_confitem()->numberjmp_msec; }
+
 const int CONFIG::get_history_size(){ return get_confitem()->history_size; }
 const int CONFIG::get_historyview_size(){ return get_confitem()->historyview_size; }
 const int CONFIG::get_aahistory_size(){ return get_confitem()->aahistory_size; }
@@ -361,6 +419,9 @@ void CONFIG::set_list_abone_regex_thread( std::list< std::string >& regex )
 }
 
 
+const int CONFIG::get_remove_old_abone_thread(){ return get_confitem()->remove_old_abone_thread; } 
+void CONFIG::set_remove_old_abone_thread( const int remove ){ get_confitem()->remove_old_abone_thread = remove; }
+
 const int CONFIG::get_abone_number_thread(){ return get_confitem()->abone_number_thread; } 
 void CONFIG::set_abone_number_thread( const int number ){ get_confitem()->abone_number_thread = number; }
 
@@ -403,13 +464,15 @@ const bool CONFIG::get_expand_sidebar(){ return get_confitem()->expand_sidebar;
 
 const bool CONFIG::get_expand_rpane(){ return get_confitem()->expand_rpane; }
 
+// ペーンの境界をクリックしてサイドバーを開け閉めする
+const bool CONFIG::get_open_sidebar_by_click(){ return get_confitem()->open_sidebar_by_click; }
 
 // 次スレ検索の類似度のしきい値
 const int CONFIG::get_threshold_next(){ return get_confitem()->threshold_next; }
 
 // 次スレを開いたときにお気に入りのアドレスと名前を自動更新
-const bool CONFIG::get_replace_favorite_next(){ return get_confitem()->replace_favorite_next; }
-void CONFIG::set_replace_favorite_next( const bool set ){ get_confitem()->replace_favorite_next = set; }
+const int CONFIG::get_replace_favorite_next(){ return get_confitem()->replace_favorite_next; }
+void CONFIG::set_replace_favorite_next( const int mode ){ get_confitem()->replace_favorite_next = mode; }
 
 // お気に入りの自動更新をするかダイアログを出す
 const bool CONFIG::show_diag_replace_favorite(){ return get_confitem()->show_diag_replace_favorite; }
@@ -424,13 +487,40 @@ const bool CONFIG::get_check_update_board(){ return get_confitem()->check_update
 // 起動時にお気に入りを自動でチェックする
 const bool CONFIG::get_check_update_boot(){ return get_confitem()->check_update_boot; }
 
+// お気に入り登録時に重複項目を登録するか ( 0: 登録する 1: ダイアログ表示 2: 登録しない )
+const int CONFIG::get_check_favorite_dup(){ return get_confitem()->check_favorite_dup; }
+void CONFIG::set_check_favorite_dup( const int check ){ get_confitem()->check_favorite_dup = check; }
+
+// お気に入り登録時に挿入先ダイアログを表示する ( 0 : 表示する 1: 表示せず先頭に追加 2: 表示せず最後に追加 )
+const int CONFIG::get_show_favorite_select_diag(){ return get_confitem()->show_favorite_select_diag; }
+
 // Ctrl+qでウィンドウを閉じない
 const bool CONFIG::get_disable_close(){ return get_confitem()->disable_close; }
 
+// メニューバーを非表示にした時にダイアログを表示
+const bool CONFIG::get_show_hide_menubar_diag(){ return get_confitem()->show_hide_menubar_diag; }
+void CONFIG::set_show_hide_menubar_diag( const bool set ){ get_confitem()->show_hide_menubar_diag = set; }
+
+
 // まちBBSの取得に offlaw.cgi を使用する
 const bool CONFIG::get_use_machi_offlaw(){ return get_confitem()->use_machi_offlaw; }
 void CONFIG::set_use_machi_offlaw( const bool set ){ get_confitem()->use_machi_offlaw = set; }
 
+// 書き込み履歴のあるスレを削除する時にダイアログを表示
+const bool CONFIG::get_show_del_written_thread_diag(){ return get_confitem()->show_del_written_thread_diag; }
+void CONFIG::set_del_written_thread_diag( const bool set ){ get_confitem()->show_del_written_thread_diag = set; }
+
+// スレを削除する時に画像キャッシュも削除する ( 0: ダイアログ表示 1: 削除 2: 削除しない )
+const int CONFIG::get_delete_img_in_thread(){ return get_confitem()->delete_img_in_thread; }
+void CONFIG::set_delete_img_in_thread( const int set ){ get_confitem()->delete_img_in_thread = set; }
+
+// FIFOの作成などにエラーがあったらダイアログを表示する
+const bool CONFIG::get_show_diag_fifo_error(){ return get_confitem()->show_diag_fifo_error; }
+void CONFIG::set_show_diag_fifo_error( const bool set ){ get_confitem()->show_diag_fifo_error = set; }
+
+// 指定した分ごとにセッションを自動保存 (0: 保存しない)
+const int CONFIG::get_save_session(){ return get_confitem()->save_session; }
+
 
 #ifdef HAVE_MIGEMO_H
 const std::string& CONFIG::get_migemodict_path() { return get_confitem()->migemodict_path; }
