@@ -55,9 +55,24 @@ namespace CONFIG
     // ツリービューの行間スペース
     const int get_tree_ypad();
 
+    // ツリービューにエクスパンダを表示
+    const bool get_tree_show_expanders();
+
+    // ツリービューのレベルインデント調整量(ピクセル)
+    const int get_tree_level_indent();
+
+    // カテゴリを開いたときにツリービューをスクロールする
+    const bool get_scroll_tree();
+
     // 各ビューと枠との間の余白
     const int get_view_margin();
 
+    // スクロールバーを左に配置
+    const bool get_left_scrbar();
+
+    // スレ一覧で古いスレも表示 	 
+    const bool get_show_oldarticle();
+
     // フォント
     const std::string& get_fontname( const int id );
     void set_fontname( const int id, const std::string& fontname );
@@ -143,7 +158,8 @@ namespace CONFIG
     void set_proxy_port_for_data( const int port );
 
     // ローダのバッファサイズ
-    const int get_loader_bufsize();
+    const int get_loader_bufsize();  // 一般
+    const int get_loader_bufsize_board();  // スレ一覧読み込み用
 
     // ローダのタイムアウト値
     const int get_loader_timeout();
@@ -155,6 +171,9 @@ namespace CONFIG
     const bool get_use_ipv6();
     void set_use_ipv6( const bool set );
 
+    // 同一ホストに対する最大コネクション数( 1 または 2 )
+    const int get_connection_num();
+
     // リンクをクリックしたときに実行するコマンド
     const std::string& get_command_openurl();
     void set_command_openurl( const std::string& command );
@@ -197,6 +216,14 @@ namespace CONFIG
     const bool get_show_ssspicon();
     void set_show_sssp_icon( const bool show );
 
+    // インライン画像の最大幅と高さ
+    const int get_embimg_width();
+    const int get_embimg_height();
+
+    // 画像ビューでdeleteを押したときに確認ダイアログを表示する
+    const bool get_show_delimgdiag();
+    void set_show_delimgdiag( const bool show );
+
     // 画像にモザイクかける
     const bool get_use_mosaic();
     void set_use_mosaic( const bool mosaic );
@@ -225,10 +252,6 @@ namespace CONFIG
     // 画像のメモリキャッシュ枚数
     const int get_imgcache_size();
 
-    // スレ一覧にdat落ちしたスレも表示する
-    const bool get_show_oldarticle();
-    void set_show_oldarticle( const bool showarticle );
-
     // スレ一覧で指定した値(時間)よりも後に立てられたスレを新着とみなす
     const int get_newthread_hour();
 
@@ -239,6 +262,12 @@ namespace CONFIG
     const bool get_show_deldiag();
     void set_show_deldiag( const bool show );
 
+    // スレ一覧をロードする前にキャッシュにある一覧を表示
+    const bool get_show_cached_board();
+
+    // スレ一覧でお知らせスレ(924)のアイコンを表示する
+    const bool get_show_924();
+    
     // ツリービューのスクロール量(マウスホイール上下・行数)
     const int get_tree_scroll_size();
 
@@ -295,20 +324,44 @@ namespace CONFIG
     // 書き込み中のダイアログを表示しない
     const bool get_hide_writing_dialog();
 
+    // 編集中のメッセージの保存確認ダイアログを表示する
+    const bool get_show_savemsgdiag();
+    void set_show_savemsgdiag( const bool show );
+
+    // 書き込みビューでテキストを折り返す
+    const bool get_message_wrap();
+    void set_message_wrap( const bool wrap );
+
     // 非アクティブ時に書き込みビューを折りたたむ
     const bool get_fold_message();
     void set_fold_message( const bool fold );
 
+    // 非アクティブ時に画像ビューを折りたたむ
+    const bool get_fold_image();
+
+    // 書き込み欄の日本語のON/OFF状態を保存
+    const bool get_keep_im_status();
+
     // ポップアップとカーソルの間のマージン
     const int get_margin_popup();
     void set_margin_popup( const int margin );
 
     // 画像ポップアップとカーソルの間のマージン
-    const int get_margin_imgpopup();
+    const int get_margin_imgpopup_x(); // 水平方向
+    const int get_margin_imgpopup(); // 垂直方向
+
+    // ポップアップが消えるまでの時間(ミリ秒)
+    const int get_hide_popup_msec();
+
+    // マウスジェスチャを有効
+    const bool get_enable_mg();
 
     // マウスジェスチャの判定開始半径
     const int get_mouse_radius();
 
+    // 数字入力ジャンプの待ち時間(ミリ秒)
+    const int get_numberjmp_msec();
+
     // 履歴メニューの表示数
     const int get_history_size();
 
@@ -390,6 +443,9 @@ namespace CONFIG
     void set_list_abone_word_thread( std::list< std::string >& word );
     void set_list_abone_regex_thread( std::list< std::string >& regex );
 
+    const int get_remove_old_abone_thread(); // dat落ちしたスレをNGスレタイトルリストから取り除くか( 0: ダイアログ表示 1: 取り除く 2: 除かない )
+    void set_remove_old_abone_thread( const int remove ); 
+
     const int get_abone_number_thread();
     void set_abone_number_thread( const int number );
 
@@ -418,12 +474,15 @@ namespace CONFIG
     // 3ペーン時にスレ一覧やスレビューを最大化するか
     const bool get_expand_rpane();
 
+    // ペーンの境界をクリックしてサイドバーを開け閉めする
+    const bool get_open_sidebar_by_click();
+
     // 次スレ検索の類似度のしきい値
     const int get_threshold_next();
 
     // 次スレを開いたときにお気に入りのアドレスと名前を自動更新
-    const bool get_replace_favorite_next();
-    void set_replace_favorite_next( const bool set );
+    const int get_replace_favorite_next();
+    void set_replace_favorite_next( const int mode );
 
     // お気に入りの自動更新をするかダイアログを出す
     const bool show_diag_replace_favorite();
@@ -438,13 +497,39 @@ namespace CONFIG
     // 起動時にお気に入りを自動でチェックする
     const bool get_check_update_boot();
 
+    // お気に入り登録時に重複項目を登録するか ( 0: 登録する 1: ダイアログ表示  2: 登録しない )
+    const int get_check_favorite_dup();
+    void set_check_favorite_dup( const int check );
+
+    // お気に入り登録時に挿入先ダイアログを表示する ( 0 : 表示する 1: 表示せず先頭に追加 2: 表示せず最後に追加 )
+    const int get_show_favorite_select_diag();
+
     // Ctrl+qでウィンドウを閉じない
     const bool get_disable_close();
 
+    // メニューバーを非表示にした時にダイアログを表示
+    const bool get_show_hide_menubar_diag();
+    void set_show_hide_menubar_diag( const bool set );
+
     // まちBBSの取得に offlaw.cgi を使用する
     const bool get_use_machi_offlaw();
     void set_use_machi_offlaw( const bool set );
 
+    // 書き込み履歴のあるスレを削除する時にダイアログを表示
+    const bool get_show_del_written_thread_diag();
+    void set_del_written_thread_diag( const bool set );
+
+    // スレを削除する時に画像キャッシュも削除する ( 0: ダイアログ表示 1: 削除 2: 削除しない )
+    const int get_delete_img_in_thread();
+    void set_delete_img_in_thread( const int set );
+
+    // FIFOの作成などにエラーがあったらダイアログを表示する
+    const bool get_show_diag_fifo_error();
+    void set_show_diag_fifo_error( const bool set );
+
+    // 指定した分ごとにセッションを自動保存 (0: 保存しない)
+    const int get_save_session();
+
 #ifdef HAVE_MIGEMO_H
     // migemo-dictの場所
     const std::string& get_migemodict_path();
