@@ -15,7 +15,12 @@
 
 #include "jdlib/miscutil.h"
 
+#include "config/globalconf.h"
+
+#include "skeleton/admin.h"
+
 #include "cache.h"
+#include "command.h"
 
 #include <cstring>
 
@@ -37,7 +42,14 @@ CONTROL::ButtonConfig* instance_buttonconfig_bkup = NULL;
 
 CONTROL::KeyConfig* CONTROL::get_keyconfig()
 {
-    if( ! instance_keyconfig ) instance_keyconfig = new CONTROL::KeyConfig();
+    if( ! instance_keyconfig ){
+
+        instance_keyconfig = new CONTROL::KeyConfig();
+
+        // ラベルをセットしておく
+        strncpy( control_label[ CONTROL::SearchWeb ][ 1 ], CONFIG::get_menu_search_web().c_str(), MAX_CONTROL_LABEL );
+        strncpy( control_label[ CONTROL::SearchTitle ][ 1 ], CONFIG::get_menu_search_title().c_str(), MAX_CONTROL_LABEL );
+    }
 
     return instance_keyconfig;
 }
@@ -311,6 +323,10 @@ const std::string CONTROL::get_label_with_mnemonic( const int id )
             case CONTROL::AppendFavorite:   //お気に入りに追加..
                 label.replace( pos, strlen( "..." ), "(_F)..." );
                 break;
+
+            case CONTROL::OpenURL:  //URLを開く
+                label.replace( pos, strlen( "..." ), "(_U)..." );
+                break;
         }
     }
     else
@@ -333,6 +349,14 @@ const std::string CONTROL::get_label_with_mnemonic( const int id )
                 label += "(_N)";
                 break;
 
+            case CONTROL::ShowMenuBar:  // メニューバー表示
+                label += "(_M)";
+                break;
+
+            case CONTROL::ShowToolBarMain:  // メインツールバー表示
+                label += "(_M)";
+                break;
+
             case CONTROL::Home:         //先頭へ移動
                 label += "(_H)";
                 break;
@@ -389,6 +413,22 @@ const std::string CONTROL::get_label_with_mnemonic( const int id )
                 label += "(_N)";
                 break;
 
+            case CONTROL::SearchWeb: // web検索
+                label += "(_W)";
+                break;
+
+            case CONTROL::SearchTitle: // スレタイ検索
+                label += "(_T)";
+                break;
+
+            case CONTROL::SearchCacheLocal: // ログ検索(対象: 板)
+                label += "(_L)";
+                break;
+
+            case CONTROL::SearchCacheAll: // ログ検索(対象: 全て)
+                label += "(_A)";
+                break;
+
             case CONTROL::CancelMosaic: //モザイク解除
                 label += "(_M)";
                 break;
@@ -437,6 +477,134 @@ const std::string CONTROL::get_label_motions( const int id )
 }
 
 
+// 共通操作
+const bool CONTROL::operate_common( const int control, const std::string& url, SKELETON::Admin* admin )
+{
+    if( control == CONTROL::None ) return false;;
+
+    switch( control ){
+            
+            // 全てのタブを閉じる
+        case CONTROL::CloseAllTabs:
+            if( admin ) admin->set_command( "close_view", "", "closealltabs" );
+            break;
+
+            // 他のタブを閉じる
+        case CONTROL::CloseOtherTabs:
+            if( admin ) admin->set_command( "close_view", url, "closeother" );
+            break;
+
+            // 全ての更新されたタブを再読み込み
+        case CONTROL::CheckUpdateTabs:
+            if( admin ) admin->set_command( "check_update_reload_all_tabs" );
+            break;
+
+            // 右、左のタブに切り替え
+        case CONTROL::TabLeft:
+            if( admin ) admin->set_command( "tab_left" );
+            break;
+
+        case CONTROL::TabRight:
+            if( admin ) admin->set_command( "tab_right" );
+            break;
+
+        case CONTROL::TabLeftUpdated:
+            if( admin ) admin->set_command( "tab_left_updated" );
+            break;
+
+        case CONTROL::TabRightUpdated:
+            if( admin ) admin->set_command( "tab_right_updated" );
+            break;
+
+        // タブ位置(1-9)で移動
+        case CONTROL::TabNum1:
+            if( admin ) admin->set_command( "tab_num", "", "1" );
+            break;
+
+        case CONTROL::TabNum2:
+            if( admin ) admin->set_command( "tab_num", "", "2" );
+            break;
+
+        case CONTROL::TabNum3:
+            if( admin ) admin->set_command( "tab_num", "", "3" );
+            break;
+
+        case CONTROL::TabNum4:
+            if( admin ) admin->set_command( "tab_num", "", "4" );
+            break;
+
+        case CONTROL::TabNum5:
+            if( admin ) admin->set_command( "tab_num", "", "5" );
+            break;
+
+        case CONTROL::TabNum6:
+            if( admin ) admin->set_command( "tab_num", "", "6" );
+            break;
+
+        case CONTROL::TabNum7:
+            if( admin ) admin->set_command( "tab_num", "", "7" );
+            break;
+
+        case CONTROL::TabNum8:
+            if( admin ) admin->set_command( "tab_num", "", "8" );
+            break;
+
+        case CONTROL::TabNum9:
+            if( admin ) admin->set_command( "tab_num", "", "9" );
+            break;
+
+            // サイドバー表示/非表示
+        case CONTROL::ShowSideBar:
+            CORE::core_set_command( "toggle_sidebar" );
+            break;
+
+            // メニューバー表示/非表示
+        case CONTROL::ShowMenuBar:
+            CORE::core_set_command( "toggle_menubar" );
+            break;
+
+            // メインツールバー表示/非表示
+        case CONTROL::ShowToolBarMain:
+            CORE::core_set_command( "toggle_toolbarmain" );
+            break;
+
+            // URLを開くダイアログを表示
+        case CONTROL::OpenURL:
+            CORE::core_set_command( "show_openurl_diag" );
+            break;
+
+            // JD終了
+        case CONTROL::QuitJD:
+            CORE::core_set_command( "quit_jd" );
+            break;
+
+            // 最大化 / 最大化解除
+        case CONTROL::MaximizeMainWin:
+            CORE::core_set_command( "maximize_mainwin" );
+            break;
+
+            // 最小化
+        case CONTROL::IconifyMainWin:
+            CORE::core_set_command( "iconify_mainwin" );
+            break;
+
+            // サイドバー更新チェック
+        case CONTROL::CheckUpdateRoot:
+            CORE::core_set_command( "check_update_root" );
+            break;
+
+        case CONTROL::CheckUpdateOpenRoot:
+            CORE::core_set_command( "check_update_open_root" );
+            break;
+
+        default:
+            return false;
+    }
+
+    return true;
+}
+
+
 /////////////////////////////////////////////////////////
 
 
