@@ -15,6 +15,8 @@
 #include "jdlib/jdregex.h"
 #include "jdlib/tfidf.h"
 
+#include "dbimg/imginterface.h"
+
 #include "config/globalconf.h"
 
 #include "httpcode.h"
@@ -68,11 +70,12 @@ ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, boo
       m_status( STATUS_UNKNOWN ),
       m_subject( std::string() ),
       m_number( 0 ),
+      m_number_diff( 0 ),
       m_number_new( 0 ),
       m_number_load( 0 ),
       m_number_before_load( 0 ),
       m_number_seen( 0 ),
-      m_number_max( MAX_RESNUMBER ),
+      m_number_max( 0 ),
       m_write_fixname( 0 ),
       m_write_fixmail( 0 ),
       m_abone_transparent( false ),
@@ -81,7 +84,8 @@ ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, boo
       m_bookmarked_thread( false ),
       m_cached( cached ),
       m_read_info( 0 ),
-      m_save_info( 0 )
+      m_save_info( false ),
+      m_924( false )
 {
 #ifdef _DEBUG
 //    std::cout << "ArticleBase::ArticleBase : " << m_id << std::endl;
@@ -138,6 +142,19 @@ const std::string ArticleBase::get_org_url()
 }
 
 
+// スレ立て時刻( string型 )
+const std::string& ArticleBase::get_since_date()
+{
+    if( m_since_date.empty()
+        || SESSION::get_col_since_time() == MISC::TIME_PASSED ){
+
+        m_since_date = MISC::timettostr( get_since_time(), SESSION::get_col_since_time() );
+    }
+
+    return m_since_date;
+}
+
+
 // スレ速度
 const int ArticleBase::get_speed()
 {
@@ -305,7 +322,7 @@ std::list< int > ArticleBase::get_res_with_url()
 //
 // mode_or == true なら OR抽出
 //
-std::list< int > ArticleBase::get_res_query( const std::string& query, bool mode_or )
+const std::list< int > ArticleBase::get_res_query( const std::string& query, const bool mode_or )
 {
     if( empty() ){ std::list< int > tmp; return tmp; }
 
@@ -392,8 +409,8 @@ void ArticleBase::set_org_host( const std::string& host )
 #ifdef _DEBUG
     std::cout << "ArticleBase::set_org_host : " << m_id << std::endl
               << "m_url = " << m_url << std::endl
-              << "host = " << host << std::endl
-              << "org_host = " << m_org_host << std::endl;
+              << "org_host = " << m_org_host
+              << " -> " << host << std::endl;
 #endif
 
         m_org_host = host;
@@ -449,10 +466,12 @@ void ArticleBase::set_number( const int number, const bool is_online )
 {
     if( ! number ) return;
 
+    m_number_diff = 0;
     m_status &= ~STATUS_BROKEN_SUBJECT;
 
     if( number > m_number ){
 
+        m_number_diff = number - m_number;
         m_number = number;
 
         // キャッシュがあって更新可能になった場合は
@@ -486,6 +505,22 @@ void ArticleBase::set_number_seen( const int number_seen )
 }
 
 
+// 最終書き込み時間( string型 )
+const std::string& ArticleBase::get_write_date()
+{
+    if( m_write_time.tv_sec ){
+
+        if( m_write_time_date.empty() 
+            || SESSION::get_col_write_time() == MISC::TIME_PASSED ){
+        
+            m_write_time_date = MISC::timettostr( m_write_time.tv_sec, SESSION::get_col_write_time() );
+        }
+    }
+
+    return m_write_time_date;
+}
+
+
 //
 // 書き込み時間更新
 //
@@ -496,7 +531,7 @@ void ArticleBase::update_writetime()
     if( CONFIG::get_save_post_history() && gettimeofday( &tv, &tz ) == 0 ){
 
         m_write_time = tv;
-        m_write_time_date = MISC::timettostr( m_write_time.tv_sec );
+        m_write_time_date = std::string();
 
 #ifdef _DEBUG
         std::cout << "ArticleBase::update_writetime : " << m_write_time.tv_sec << " " << m_write_time_date << std::endl;
@@ -552,11 +587,16 @@ const bool ArticleBase::enable_load()
 //
 const bool ArticleBase::is_finished()
 {
+    if( is_cached() && ! enable_load() &&  m_number_max && get_number_seen() >= m_number_max ){
+
 #ifdef _DEBUG
-    if( get_number_seen() >= get_number_max() ) std::cout << is_cached() << " " << !enable_load() << " " << get_number_seen() << " " << get_subject() << std::endl;
+        std::cout << "ArticleBase::is_finished :  seen = " << get_number_seen() << " max = " << m_number_max << " : " << get_subject() << std::endl;
 #endif
 
-    return ( is_cached() && ! enable_load() && get_number_seen() >= get_number_max() );
+        return true;
+    }
+
+    return false;
 }
 
 
@@ -947,10 +987,11 @@ void ArticleBase::unlock_impl()
 #endif
 
     m_nodetree->terminate_load(); // deleteする前にスレッド停止
-    m_nodetree.clear();
 
-    // スレ情報保存
+    // スレ情報保存 	 
     save_info( false );
+
+    m_nodetree.clear();
 }
 
 
@@ -967,6 +1008,16 @@ const bool ArticleBase::is_loading()
 }
 
 
+//
+// 更新チェック中か
+//
+const bool ArticleBase::is_checking_update()
+{
+    if( ! is_loading() ) return false;
+
+    return m_nodetree->is_checking_update();
+}
+
 
 //
 // ロード停止
@@ -1001,28 +1052,46 @@ void ArticleBase::download_dat( const bool check_update )
     struct timezone tz;
     if( gettimeofday( &tv, &tz ) != 0 ) tv.tv_sec = 0;
 
+    // 更新チェック可能か判定する
     if( check_update ){
 
-        if( ! SESSION::is_online() ) return;
-
-        // 既に更新状態の時はチェックしない
-        if( enable_load() ){
-
-            // 次のスレを更新チェック
-            CORE::get_checkupdate_manager()->pop_front();
-
-            return;
-        }
-
         // 一度更新チェックしたらしばらくは再チェックできないようにする
         time_t passed = 0;
         if( tv.tv_sec ) passed = MAX( 0, tv.tv_sec - m_check_update_time.tv_sec );
 
+        if( ! SESSION::is_online()
+            || ! enable_check_update()
+            || is_loading()
+            || enable_load() // 既に新着あり状態の時はチェックしない
+            || ( m_status & STATUS_OLD )
+            || ( passed <= CHECKUPDATE_MINSEC )
+            )
+        {
 #ifdef _DEBUG
-        std::cout << "check_update passed = " << passed << std::endl;
+            std::cout << "skipped : passed = " << passed << " enable_load = " << enable_load()
+                      << " loading = " << is_loading()
+                      << std::endl;
 #endif
 
-        if( passed <= CHECKUPDATE_MINSEC ) return;
+            // スレビューのタブとサイドバーのアイコン表示を更新
+
+            // JDが異常終了すると、お気に入りに+が付いてないのにスレが更新可能状態になっていて
+            // 更新チェックが行われてなくなるときがある。このバグは次の様にして再現出来た
+            // (1) 端末からJDを起動する
+            // (2) 適当な板のスレ一覧を開く
+            // (3) お気に入りに適当なスレを登録
+            // (4) そのスレを読み込む。読み込んだらスレビューは閉じないままにしておく
+            // (5) スレ一覧を更新してそのスレに + マークを付ける。お気に入りにも + が付く
+            // (6) そのスレのスレビューを閉じる ( スレ情報を保存 )
+            // (7) 端末で Ctrl+c を押してJDを強制終了
+            // (8) 再起動してお気に入りの復元をしない
+            // (9) お気に入りの + が消えている。以後更新チェックも行われない
+
+            CORE::core_set_command( "toggle_article_icon", m_url);
+            CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
+
+            return;
+        }
     }
 
     if( SESSION::is_online() && tv.tv_sec ) m_check_update_time = tv;
@@ -1169,7 +1238,7 @@ void ArticleBase::slot_load_finished()
     if( m_code != HTTP_ERR ){
 
         // DAT落ち
-        if( m_code == HTTP_REDIRECT || m_code == HTTP_NOT_FOUND ){
+        if( m_code == HTTP_MOVED_PERM || m_code == HTTP_REDIRECT || m_code == HTTP_NOT_FOUND || m_code == HTTP_OLD ){
             m_status &= ~STATUS_NORMAL;
             m_status |= STATUS_OLD;
             CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
@@ -1196,7 +1265,8 @@ void ArticleBase::slot_load_finished()
 #endif
 
         // スレタブとお気に入りとスレ一覧のアイコンに更新マークをつける
-        if( m_code == HTTP_OK || m_code == HTTP_PARTIAL_CONTENT ){
+        if( m_code == HTTP_OK // まちBBSは206が返らない(200か304のみ)
+            || m_code == HTTP_PARTIAL_CONTENT ){
 
             show_updateicon( true );
 
@@ -1259,7 +1329,7 @@ void ArticleBase::slot_load_finished()
 #endif
             int value = 0;
 
-            const std::list< DBTREE::ArticleBase* >& list_subject = DBTREE::board_list_subject( m_url );
+            const std::vector< DBTREE::ArticleBase* >& list_subject = DBTREE::board_list_subject( m_url );
 
             // subjectがキャッシュにある場合は TFIDF を使って類似度チェック
             if( list_subject.size() ){
@@ -1310,9 +1380,7 @@ void ArticleBase::slot_load_finished()
                 copy_article_info( m_url_pre_article );
 
                 // お気に入りのアドレスと名前を自動更新
-                if( CONFIG::get_replace_favorite_next() ){
-                    CORE::core_set_command( "replace_favorite_thread", "", m_url_pre_article, m_url );
-                }
+                CORE::core_set_command( "replace_favorite_thread", "", m_url_pre_article, m_url );
 
                 // 前スレにしおりがセットされていたらしおりをつける
                 if( DBTREE::is_bookmarked_thread( m_url_pre_article ) ){
@@ -1337,9 +1405,14 @@ void ArticleBase::slot_load_finished()
 
     else{
 
-        // スレが更新している場合はスレ情報を更新
-        if( m_number_new
+        // スレ情報を更新
+        if( m_number_new // スレが更新している場合
+
             || m_date_modified != m_old_modified // ときどき modified が誤って返るときがあるので最新の値を保存しておく
+
+            || ( SESSION::is_online() && ( m_status & STATUS_UPDATE )
+                 && ( m_code == HTTP_OK || m_code == HTTP_NOT_MODIFIED ) )  // 間違って更新可能マークが付いている場合はマークを消す
+
             ){
 
             m_cached = true;
@@ -1414,9 +1487,8 @@ void ArticleBase::show_updateicon( const bool update )
             m_save_info = true;
             m_status |= STATUS_UPDATE;
 
-            // スレビューのタブのアイコン表示を更新
+            // スレビューのタブとサイドバーのアイコン表示を更新
             CORE::core_set_command( "toggle_article_icon", m_url);
-
             CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
         }
     }
@@ -1460,11 +1532,88 @@ void ArticleBase::delete_cache( const bool cache_only )
 
     if( empty() ) return;
 
-    if( ! cache_only && m_bookmarked_thread ){
-        SKELETON::MsgDiag mdiag( NULL, "「" + get_subject() + "」にはしおりが付けられています。\n\nスレを削除しますか？\n\nしおりを解除するにはスレの上で右クリックしてしおり解除を選択してください。"
-                                  ,false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-        mdiag.set_default_response( Gtk::RESPONSE_YES );
-        if( mdiag.run() == Gtk::RESPONSE_NO ) return;
+
+    if( ! cache_only ){
+
+        if( m_bookmarked_thread ){
+
+            const std::string msg = "「" + get_subject() +
+            "」にはしおりが付けられています。\n\nスレを削除しますか？\n\nしおりを解除するにはスレの上で右クリックしてしおり解除を選択してください。";
+
+            SKELETON::MsgDiag mdiag( NULL, msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            mdiag.set_default_response( Gtk::RESPONSE_YES );
+            if( mdiag.run() != Gtk::RESPONSE_YES ) return;
+        }
+
+        if( CONFIG::get_show_del_written_thread_diag() && m_write_time.tv_sec ){
+
+            const std::string msg = "「" + get_subject() + "」には書き込み履歴が残っています。\n\nスレを削除しますか？";
+
+            SKELETON::MsgCheckDiag mdiag( NULL, msg,
+                                          "今後表示しない(常に削除)(_D)",
+                                          Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+
+            if( mdiag.run() != Gtk::RESPONSE_YES ) return;
+
+            if( mdiag.get_chkbutton().get_active() ) CONFIG::set_del_written_thread_diag( false );
+        }
+
+        // スレ内の画像キャッシュ削除
+        if( CONFIG::get_delete_img_in_thread() != 2 ){
+
+            bool delete_img_cache = false;
+
+            std::list< std::string > list_urls = get_nodetree()->get_urls();
+            std::list< std::string >::iterator it = list_urls.begin();
+            for( ; it != list_urls.end(); ++it ){
+
+                if( DBIMG::get_type_ext( *it ) != DBIMG::T_UNKNOWN && DBIMG::is_cached( *it ) ){
+                    delete_img_cache = true;
+                    break;
+                }
+            }
+
+            if( delete_img_cache ){
+
+                if( CONFIG::get_delete_img_in_thread() == 0 ){
+
+                    const std::string msg = "「" + get_subject() + "」には画像が貼られています。\n\n画像のキャッシュも削除しますか？";
+
+                    SKELETON::MsgCheckDiag mdiag( NULL, msg,
+                                                  "今後表示しない(常に削除しない)(_D)",
+                                                  Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
+
+                    mdiag.add_button( "スレ削除中止(_C)", Gtk::RESPONSE_CANCEL );
+                    mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+                    Gtk::Button button( Gtk::Stock::NO );
+                    mdiag.add_default_button( &button, Gtk::RESPONSE_NO );
+
+                    const int ret = mdiag.run();
+                    if( ret == Gtk::RESPONSE_CANCEL ) return;
+                    if( ret != Gtk::RESPONSE_YES ){
+
+                        if( mdiag.get_chkbutton().get_active() ) CONFIG::set_delete_img_in_thread( 2 );
+                        delete_img_cache = false;
+                    }
+                }
+
+                if( delete_img_cache ){
+
+                    it = list_urls.begin();
+                    for( ; it != list_urls.end(); ++it ){
+
+                        if( DBIMG::get_type_ext( *it ) != DBIMG::T_UNKNOWN && DBIMG::is_cached( *it ) ){
+
+#ifdef _DEBUG
+                            std::cout << "delete " << *it << std::endl;
+#endif
+                            DBIMG::delete_cache( *it );
+                        }
+                    }
+                }
+
+            }
+        }
     }
 
     m_number_load = m_number_seen = m_number_before_load = 0;
@@ -1502,10 +1651,10 @@ void ArticleBase::delete_cache( const bool cache_only )
         m_bookmarked_thread = false;
     
         // info 削除
-        if( CACHE::file_exists( m_path_article_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_info.c_str() );
+        if( CACHE::file_exists( m_path_article_info ) == CACHE::EXIST_FILE ) unlink( to_locale_cstr( m_path_article_info ) );
 
         // 拡張info 削除
-        if( CACHE::file_exists( m_path_article_ext_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_ext_info.c_str() );
+        if( CACHE::file_exists( m_path_article_ext_info ) == CACHE::EXIST_FILE ) unlink( to_locale_cstr( m_path_article_ext_info ) );
 
         // お気に入りから削除
         CORE::core_set_command( "remove_favorite", m_url );
@@ -1513,7 +1662,7 @@ void ArticleBase::delete_cache( const bool cache_only )
 
     // キャッシュ削除
     std::string path_dat = CACHE::path_dat( m_url );
-    if( CACHE::file_exists( path_dat ) == CACHE::EXIST_FILE ) unlink( path_dat.c_str() );
+    if( CACHE::file_exists( path_dat ) == CACHE::EXIST_FILE ) unlink( to_locale_cstr( path_dat ) );
 
     // BoardViewの行を更新
     CORE::core_set_command( "update_board_item", DBTREE::url_subject( m_url ), m_id );
@@ -1569,6 +1718,9 @@ void ArticleBase::read_info()
 
     m_read_info = true;
 
+    const int status_old = m_status;
+    bool saveinfo = false;
+
     // 情報ファイルのパスをセット
     if( m_path_article_info.empty() ) SET_INFOPATH();
 
@@ -1624,8 +1776,6 @@ void ArticleBase::read_info()
                 m_write_time.tv_sec = ( atoi( ( *(it_tmp++) ).c_str() ) << 16 ) + atoi( ( *(it_tmp++) ).c_str() );
                 m_write_time.tv_usec = atoi( ( *(it_tmp++) ).c_str() );
             }
-
-            if( m_write_time.tv_sec ) m_write_time_date = MISC::timettostr( m_write_time.tv_sec );
         }
 
         // write name
@@ -1769,7 +1919,7 @@ void ArticleBase::read_info()
         }
         
         m_number_before_load = m_number_load;
-        m_save_info = true;
+        saveinfo = true;
         unlock_impl();
 
 #ifdef _DEBUG
@@ -1779,6 +1929,15 @@ void ArticleBase::read_info()
 
     if( m_number < m_number_load ) m_number = m_number_load;
 
+    // infoファイル読み込み前に既にDAT落ち状態になっていた場合は
+    // 状態を DAT 落ちに戻しておく
+    if( ( status_old & STATUS_OLD ) && ( m_status & STATUS_NORMAL ) ){
+        m_status &= ~STATUS_NORMAL;
+        m_status |= STATUS_OLD;
+        saveinfo = true;
+    }
+    if( saveinfo ) save_info( true );
+
 #ifdef _DEBUG
     std::cout << "ArticleBase::read_info file = " << m_path_article_ext_info << std::endl;
 
@@ -1831,18 +1990,24 @@ void ArticleBase::read_info()
 // infoファイル書き込み
 //
 // キャッシュがある( is_cached() == true )　かつ
-// m_save_info = true の時に保存。save_info()を呼ぶ前にm_save_infoをセットすること。
+// m_save_info = true かつ nodetree が作られている時に保存。
+// save_info()を呼ぶ前にm_save_infoをセットすること。
 //
 // キャッシュがあって、force = true の時は強制書き込み
-//
 void ArticleBase::save_info( const bool force )
 {
     if( empty() ) return;
     if( ! is_cached() ) return;
-    if( ! force && ! m_save_info ) return;
+    if( ! force ){
+
+        if( ! m_save_info ) return;
+        if( ! m_nodetree ) return;
+    }
+
     m_save_info = false;
 
     if( m_path_article_ext_info.empty() ) return;
+    if( ! CACHE::mkdir_boardroot( m_url ) ) return;
 
 #ifdef _DEBUG
     std::cout << "ArticleBase::save_info force = " << force << std::endl;
