@@ -362,6 +362,11 @@ void DBTREE::board_download_subject( const std::string& url, const std::string&
     DBTREE::get_board( url )->download_subject( url_update_view, false );
 }
 
+void DBTREE::board_read_subject_from_cache( const std::string& url )
+{
+    DBTREE::get_board( url )->download_subject( std::string(), true );
+}
+
 const bool DBTREE::board_is_loading( const std::string& url )
 {
     return DBTREE::get_board( url )->is_loading();
@@ -625,6 +630,12 @@ void DBTREE::board_set_number_max_res( const std::string& url, const int number
     DBTREE::get_board( url )->set_number_max_res( number );
 }
 
+// datの最大サイズ(Kバイト)
+const int DBTREE::board_get_max_dat_lng( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_max_dat_lng();
+}
+
 const time_t DBTREE::board_get_live_sec( const std::string& url )
 {
     return DBTREE::get_board( url )->get_live_sec();
@@ -769,6 +780,13 @@ const std::string DBTREE::article_key( const std::string& url )
 }
 
 
+// 移転する前のオリジナルのURL
+const std::string DBTREE::article_org_host( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_org_host();
+}
+
+
 const time_t DBTREE::article_since_time( const std::string& url )
 {
     return DBTREE::get_article( url )->get_since_time();
@@ -915,10 +933,19 @@ void DBTREE::article_clear_post_history( const std::string& url )
 }
 
 
+// ユーザーエージェント
+// ダウンロード用
 const std::string& DBTREE::get_agent( const std::string& url )
 {
     return DBTREE::get_board( url )->get_agent();
 }
+
+// 書き込み用
+const std::string& DBTREE::get_agent_w( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_agent_w();
+}
+
     
 const std::string DBTREE::get_proxy_host( const std::string& url )
 {
@@ -978,6 +1005,12 @@ const int DBTREE::message_count( const std::string& url )
     return DBTREE::get_board( url )->message_count();
 }
 
+// 特殊文字書き込み可能か( pass なら可能、 change なら不可 )
+const std::string DBTREE::get_unicode( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_unicode();
+}
+
 const std::string& DBTREE::write_name( const std::string& url )
 {
     return DBTREE::get_article( url )->get_write_name();
@@ -1053,6 +1086,12 @@ bool DBTREE::article_save_dat( const std::string& url, const std::string& path_t
 }
 
 
+// 全スレ情報の保存
+void DBTREE::save_articleinfo_all()
+{
+    DBTREE::get_root()->save_articleinfo_all();
+}
+
 
 void DBTREE::article_update_writetime( const std::string& url )
 {
