@@ -114,6 +114,7 @@ namespace DBTREE
     const std::string board_str_code( const std::string& url );
     void board_save_info( const std::string& url );
     void board_download_subject( const std::string& url, const std::string& url_update_view );
+    void board_read_subject_from_cache( const std::string& url );
     const bool board_is_loading( const std::string& url );
     void board_stop_load( const std::string& url );
     std::vector< DBTREE::ArticleBase* >& board_list_subject( const std::string& url );
@@ -126,7 +127,9 @@ namespace DBTREE
     const int board_view_sort_pre_mode( const std::string& url );
     void board_set_view_sort_pre_mode( const std::string& url, int mode );
     const bool board_check_noname( const std::string& url );
-    void board_set_check_noname( const std::string& url, bool check );
+    void board_set_check_noname( const std::string& url, const bool check );
+    const bool board_show_oldlog( const std::string& url );
+    void board_set_show_oldlog( const std::string& url, const bool show );
     const int board_get_mode_local_proxy( const std::string& url );
     const std::string& board_get_local_proxy( const std::string& url );
     const int board_get_local_proxy_port( const std::string& url );
@@ -169,6 +172,10 @@ namespace DBTREE
 
     const int board_get_number_max_res( const std::string& url );
     void board_set_number_max_res( const std::string& url, const int number );
+
+    // datの最大サイズ(Kバイト)
+    const int board_get_max_dat_lng( const std::string& url );
+
     const time_t board_get_live_sec( const std::string& url );
     void board_set_live_sec( const std::string& url, time_t sec );
     const time_t board_last_access_time( const std::string& url );
@@ -182,15 +189,17 @@ namespace DBTREE
     // キャッシュ内のログ検索
     // ArticleBase のアドレスをリスト(list_article)にセットして返す
     // query が空の時はキャッシュにあるログを全てヒットさせる
+    // bm がtrueの時、しおりが付いている(スレ一覧でしおりを付けた or レスに一つでもしおりが付いている)スレのみを対象に検索する
     void search_cache_all( std::vector< DBTREE::ArticleBase* >& list_article,
-                           const std::string& query, const bool mode_or, const bool& stop );
+                           const std::string& query, const bool mode_or, const bool bm, const bool& stop );
     void search_cache( const std::string& url, std::vector< DBTREE::ArticleBase* >& list_article,
-                       const std::string& query, const bool mode_or, const bool& stop );
+                       const std::string& query, const bool mode_or, const bool bm, const bool& stop );
     
     // article 系
     const bool article_is_cached( const std::string& url ); // キャッシュにあるかどうか
     const std::string article_id( const std::string& url ); // 拡張子込み "12345.dat" みたいに
     const std::string article_key( const std::string& url ); // idから拡張子を取ったもの。書き込み用
+    const std::string article_org_host( const std::string& url ); // 移転する前のオリジナルのURL
     const time_t article_since_time( const std::string& url );
     const std::string article_since_date( const std::string& url );
     const time_t article_time_modified( const std::string& url ); // スレの更新時間( time_t )
@@ -227,11 +236,15 @@ namespace DBTREE
     // キャッシュ保存
     bool article_save_dat( const std::string& url, const std::string& path_to );
 
+    // 全スレ情報の保存
+    void save_articleinfo_all();
+
     void article_update_writetime( const std::string& url );
     size_t article_lng_dat( const std::string& url );
 
     // ユーザーエージェント
-    const std::string& get_agent( const std::string& url );
+    const std::string& get_agent( const std::string& url );   // ダウンロード用
+    const std::string& get_agent_w( const std::string& url ); // 書き込み用
 
     // 読み込み用プロキシ
     const std::string get_proxy_host( const std::string& url );
@@ -260,6 +273,8 @@ namespace DBTREE
     // 最大書き込みバイト数
     const int message_count( const std::string& url );
 
+    // 特殊文字書き込み可能か( pass なら可能、 change なら不可 )
+    const std::string get_unicode( const std::string& url );
 
     // 書き込み時の名前とメール
     const std::string& write_name( const std::string& url );
@@ -334,6 +349,10 @@ namespace DBTREE
     // 全articlebaseクラスのあぼーん状態の更新
     void update_abone_all_article();
 
+    // 全articlebaseクラスの書き込み時間とスレ立て時間の文字列をリセット
+    void reset_all_write_date();
+    void reset_all_since_date();
+
     // レスあぼーん
     // グローバルなあぼーん情報は globalconf が管理
     const std::list< std::string >& get_abone_list_id( const std::string& url );
