@@ -20,6 +20,8 @@
 #include "control/controlutil.h"
 #include "control/controlid.h"
 
+#include "config/globalconf.h"
+
 #include "cache.h"
 #include "command.h"
 #include "sharedbuffer.h"
@@ -148,7 +150,10 @@ void ImageViewBase::setup_common()
     action_group()->add( Gtk::Action::create( "CloseOther", "他の画像(_O)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_other_views ) );
     action_group()->add( Gtk::Action::create( "CloseLeft", "左←の画像(_L)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_left_views ) );
     action_group()->add( Gtk::Action::create( "CloseRight", "右→の画像(_R)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_right_views ) );
-    action_group()->add( Gtk::Action::create( "CloseError", "読み込みエラーの画像(_E)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_error_views ) );
+    action_group()->add( Gtk::Action::create( "CloseError404", "エラー画像(404,403のみ)(_E)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_error_views ) );
+    action_group()->add( Gtk::Action::create( "CloseError503", "エラー画像(timeout,503以外)(_T)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_notimeout_error_views ) );
+    action_group()->add( Gtk::Action::create( "CloseErrorAll", "エラー画像(読込み中含め全て)(_W)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_all_error_views ) );
+    action_group()->add( Gtk::Action::create( "CloseNoError", "エラー以外の画像(_N)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_noerror_views ) );
     action_group()->add( Gtk::Action::create( "CloseAll", "全ての画像(_A)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_all_views ) );
 
     action_group()->add( Gtk::ToggleAction::create( "LockTab", "タブをロックする(_K)", std::string(), false ),
@@ -156,6 +161,8 @@ void ImageViewBase::setup_common()
 
     action_group()->add( Gtk::Action::create( "OpenBrowser", ITEM_NAME_OPEN_BROWSER + std::string( "(_W)" ) ),
                          sigc::mem_fun( *this, &ImageViewBase::slot_open_browser ) );
+    action_group()->add( Gtk::Action::create( "OpenCacheBrowser", ITEM_NAME_OPEN_CACHE_BROWSER + std::string( "(_X)" ) ),
+                         sigc::mem_fun( *this, &ImageViewBase::slot_open_cache_browser ) );
     action_group()->add( Gtk::Action::create( "OpenRef", "参照元のレスを開く(_O)"), sigc::mem_fun( *this, &ImageViewBase::slot_open_ref ) );
     action_group()->add( Gtk::Action::create( "CopyURL", ITEM_NAME_COPY_URL + std::string( "(_U)" ) ), sigc::mem_fun( *this, &ImageViewBase::slot_copy_url ) );
     action_group()->add( Gtk::Action::create( "Save", "Save"), sigc::mem_fun( *this, &ImageViewBase::slot_save ) );
@@ -209,6 +216,7 @@ void ImageViewBase::setup_common()
     "<separator/>"
 
     "<menuitem action='OpenBrowser'/>"
+    "<menuitem action='OpenCacheBrowser'/>"
     "<menuitem action='OpenRef'/>"
     + usrcmd
     + std::string( 
@@ -262,7 +270,12 @@ void ImageViewBase::setup_common()
     "<menuitem action='CloseOther'/>"
     "<menuitem action='CloseLeft'/>"
     "<menuitem action='CloseRight'/>"
-    "<menuitem action='CloseError'/>"
+    "<separator/>"
+    "<menuitem action='CloseError404'/>"
+    "<menuitem action='CloseError503'/>"
+    "<menuitem action='CloseErrorAll'/>"
+    "<separator/>"
+    "<menuitem action='CloseNoError'/>"
     "</menu>"
     "<separator/>"
 
@@ -270,6 +283,7 @@ void ImageViewBase::setup_common()
     "<separator/>"
 
     "<menuitem action='OpenBrowser'/>"
+    "<menuitem action='OpenCacheBrowser'/>"
     "<menuitem action='OpenRef'/>"
     "<separator/>"
 
@@ -501,14 +515,40 @@ void ImageViewBase::slot_close_right_views()
 
 
 //
-// エラーの画像を閉じる
+// エラーの画像を閉じる( HTTP404 のみ )
 //
 void ImageViewBase::slot_close_error_views()
 {
-    IMAGE::get_admin()->set_command( "close_error_views" );
+    IMAGE::get_admin()->set_command( "close_error_views", "", "" );
 }
 
 
+//
+// エラーの画像を閉じる( timeout, 503 以外 )
+//
+void ImageViewBase::slot_close_notimeout_error_views()
+{
+    IMAGE::get_admin()->set_command( "close_error_views", "", "notimeout" );
+}
+
+
+//
+// エラーの画像を閉じる( 全て )
+//
+void ImageViewBase::slot_close_all_error_views()
+{
+    IMAGE::get_admin()->set_command( "close_error_views", "", "all" );
+}
+
+
+//
+// エラー以外の画像を閉じる
+//
+void ImageViewBase::slot_close_noerror_views()
+{
+    IMAGE::get_admin()->set_command( "close_noerror_views" );
+}
+
 
 //
 // 全ての画像を閉じる
@@ -551,19 +591,25 @@ void ImageViewBase::delete_view_impl( const bool show_diag )
 
     if( show_diag ){
 
-        if( !m_img->is_protected() ){
-
-            SKELETON::MsgDiag mdiag( get_parent_win(),
-                                     "画像を削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-            mdiag.set_default_response( Gtk::RESPONSE_NO );
-            if( mdiag.run() != Gtk::RESPONSE_YES ) return;
-        }
-        else{
+        if( m_img->is_protected() ){
 
             SKELETON::MsgDiag mdiag( get_parent_win(), "キャッシュ保護されています" );
             mdiag.run();
             return;
         }
+        else if( CONFIG::get_show_delimgdiag() ){
+
+            SKELETON::MsgCheckDiag mdiag( get_parent_win(),
+                                          "画像を削除しますか？",
+                                          "今後表示しない(常に削除) (_D)",
+                                          Gtk::MESSAGE_QUESTION,
+                                          Gtk::BUTTONS_YES_NO,
+                                          Gtk::RESPONSE_NO
+                );
+
+            if( mdiag.run() != Gtk::RESPONSE_YES ) return;
+            if( mdiag.get_chkbutton().get_active() ) CONFIG::set_show_delimgdiag( false );
+        }
     }
 
     CORE::core_set_command( "delete_image", get_url() );
@@ -586,6 +632,8 @@ void ImageViewBase::clicked()
 //
 const bool ImageViewBase::operate_view( const int control )
 {
+    if( CONTROL::operate_common( control, get_url(), IMAGE::get_admin() ) ) return true;
+
 #ifdef _DEBUG
     std::cout << "ImageViewBase::operate_view control = " << control << std::endl;
 #endif
@@ -628,53 +676,6 @@ const bool ImageViewBase::operate_view( const int control )
             close_view();
             break;
 
-        case CONTROL::TabLeft:
-        case CONTROL::TabLeftUpdated:
-            IMAGE::get_admin()->set_command( "tab_left" );
-            break;
-
-        case CONTROL::TabRight:
-        case CONTROL::TabRightUpdated:
-            IMAGE::get_admin()->set_command( "tab_right" );
-            break;
-
-        // タブ位置(1-9)で移動
-        case CONTROL::TabNum1:
-            IMAGE::get_admin()->set_command( "tab_num", "", "1" );
-            break;
-
-        case CONTROL::TabNum2:
-            IMAGE::get_admin()->set_command( "tab_num", "", "2" );
-            break;
-
-        case CONTROL::TabNum3:
-            IMAGE::get_admin()->set_command( "tab_num", "", "3" );
-            break;
-
-        case CONTROL::TabNum4:
-            IMAGE::get_admin()->set_command( "tab_num", "", "4" );
-            break;
-
-        case CONTROL::TabNum5:
-            IMAGE::get_admin()->set_command( "tab_num", "", "5" );
-            break;
-
-        case CONTROL::TabNum6:
-            IMAGE::get_admin()->set_command( "tab_num", "", "6" );
-            break;
-
-        case CONTROL::TabNum7:
-            IMAGE::get_admin()->set_command( "tab_num", "", "7" );
-            break;
-
-        case CONTROL::TabNum8:
-            IMAGE::get_admin()->set_command( "tab_num", "", "8" );
-            break;
-
-        case CONTROL::TabNum9:
-            IMAGE::get_admin()->set_command( "tab_num", "", "9" );
-            break;
-
         // スクロール
         case CONTROL::ScrollUpImage:
             IMAGE::get_admin()->set_command( "scroll_up" );
@@ -702,6 +703,7 @@ const bool ImageViewBase::operate_view( const int control )
             break;
 
         case CONTROL::Save:
+        case CONTROL::SaveImageButton:
             slot_save();
             break;
 
@@ -709,31 +711,11 @@ const bool ImageViewBase::operate_view( const int control )
             delete_view_impl( true );
             break;
 
-            // サイドバー表示/非表示
-        case CONTROL::ShowSideBar:
-            CORE::core_set_command( "toggle_sidebar" );
-            break;
-
-            // メニューバー表示/非表示
-        case CONTROL::ShowMenuBar:
-            CORE::core_set_command( "toggle_menubar" );
-            break;
-
-            // メインツールバー表示/非表示
-        case CONTROL::ShowToolBarMain:
-            CORE::core_set_command( "toggle_toolbarmain" );
-            break;
-
             // お気に入りに追加
         case CONTROL::AppendFavorite:
             slot_favorite();
             break;
 
-            // URLを開くダイアログを表示
-        case CONTROL::OpenURL:
-            CORE::core_set_command( "show_openurl_diag" );
-            break;
-
         default:
             return false;
     }
@@ -1058,12 +1040,22 @@ void ImageViewBase::slot_open_browser()
 {
     if( ! m_enable_menuslot ) return;
 
-    std::string url = get_url();
-    if( m_img->is_cached() ) url = "file://" + m_img->get_cache_path();
-    CORE::core_set_command( "open_url_browser", url );
+    CORE::core_set_command( "open_url_browser", get_url() );
 }
 
 
+//
+// キャッシュをブラウザで開く
+//
+void ImageViewBase::slot_open_cache_browser()
+{
+    if( ! m_enable_menuslot ) return;
+    if( ! m_img->is_cached() ) return;
+
+    const std::string url = "file://" + m_img->get_cache_path();
+    CORE::core_set_command( "open_url_browser", url );
+}
+
 
 //
 // 参照元を開く
@@ -1245,6 +1237,13 @@ void ImageViewBase::activate_act_before_popupmenu( const std::string& url )
         }
     }
 
+    // キャッシュをブラウザで開く
+    act = action_group()->get_action( "OpenCacheBrowser" );
+    if( act ){
+        if( m_img->is_cached() ) act->set_sensitive( true );
+        else act->set_sensitive( false );
+    }
+
     // 参照元スレ
     act = action_group()->get_action( "OpenRef" );
     if( act ){
