@@ -5,6 +5,7 @@
 
 #include "messageadmin.h"
 #include "post.h"
+#include "confirmdiag.h"
 
 #include "skeleton/msgdiag.h"
 
@@ -66,6 +67,10 @@ Post::~Post()
 
 void Post::clear()
 {
+#ifdef _DEBUG
+    std::cout << "Post::clear\n";
+#endif
+
     if( m_rawdata ) free( m_rawdata );
     m_rawdata = NULL;
 
@@ -75,6 +80,10 @@ void Post::clear()
 
 void Post::emit_sigfin()
 {
+#ifdef _DEBUG
+    std::cout << "Post::emit_sigfin\n";
+#endif
+
     m_sig_fin.emit();
 
     clear();
@@ -84,6 +93,43 @@ void Post::emit_sigfin()
 }
 
 
+//
+// 書き込み中ダイアログ表示
+//
+void Post::show_writingdiag( const bool show_buttons )
+{
+    Gtk::Window* toplevel = dynamic_cast< Gtk::Window* >( m_parent->get_toplevel() );
+    if( ! toplevel ) return;
+
+    Gtk::ButtonsType buttons = Gtk::BUTTONS_NONE;
+    if( show_buttons ) buttons = Gtk::BUTTONS_OK;
+
+    if( ! m_writingdiag ){
+        m_writingdiag = new SKELETON::MsgDiag( *toplevel, "書き込み中・・・", false, Gtk::MESSAGE_INFO, buttons, false );
+        m_writingdiag->signal_response().connect( sigc::mem_fun( *this, &Post::slot_response ) );
+    }
+    m_writingdiag->show();
+
+    // gtkのバージョンによってはラベルが選択状態になっている場合があるので
+    // 選択状態を解除する
+    Gtk::Label *label = dynamic_cast< Gtk::Label* >( m_writingdiag->get_focus() );
+    if( label ) label->set_selectable( false );
+}
+
+
+//
+// 書き込み中ダイアログのボタンを押した
+//
+void Post::slot_response( int id )
+{
+#ifdef _DEBUG
+    std::cout << "Post::slot_response id = " << id << std::endl;
+#endif
+
+    if( m_writingdiag ) m_writingdiag->hide();
+}
+
+
 //
 // ポスト実行
 //
@@ -96,17 +142,7 @@ void Post::post_msg()
     m_lng_rawdata = 0;
 
     // 書き込み中ダイアログ表示
-    Gtk::Window* toplevel = dynamic_cast< Gtk::Window* >( m_parent->get_toplevel() );
-    if( ! CONFIG::get_hide_writing_dialog() && toplevel ){
-
-        if( ! m_writingdiag ) m_writingdiag = new SKELETON::MsgDiag( *toplevel, "書き込み中・・・", false, Gtk::MESSAGE_INFO, Gtk::BUTTONS_NONE, false );
-        m_writingdiag->show();
-
-        // gtkのバージョンによってはラベルが選択状態になっている場合があるので
-        // 選択状態を解除する
-        Gtk::Label *label = dynamic_cast< Gtk::Label* >( m_writingdiag->get_focus() );
-        if( label ) label->set_selectable( false );
-    }
+    if( ! CONFIG::get_hide_writing_dialog() ) show_writingdiag( false );
 
     JDLIB::LOADERDATA data;
 
@@ -127,7 +163,7 @@ void Post::post_msg()
     // http://www.w3.org/TR/html401/interact/forms.html#h-17.13.4.1
     data.contenttype = "application/x-www-form-urlencoded";
 
-    data.agent = DBTREE::get_agent( m_url );
+    data.agent = DBTREE::get_agent_w( m_url );
     data.referer = DBTREE::get_write_referer( m_url );
     data.str_post = m_msg;
     data.host_proxy = DBTREE::get_proxy_host_w( m_url );
@@ -196,7 +232,7 @@ void Post::receive_finish()
     
     // ポスト失敗
     if( get_code() != HTTP_OK
-        && ! ( get_code() == HTTP_REDIRECT && ! location().empty() ) // リダイレクトは成功(かもしれない)
+        && ! ( ( get_code() == HTTP_MOVED_PERM || get_code() == HTTP_REDIRECT ) && ! location().empty() ) // リダイレクトは成功(かもしれない)
         ){
 
         m_errmsg = get_str_code();
@@ -207,6 +243,11 @@ void Post::receive_finish()
     // 以下、code == 200、 又は 302 かつ locationがセットされている(リダイレクト) の場合
 
     JDLIB::Regex regex;
+    const size_t offset = 0;
+    bool icase = false;
+    bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
 
     std::string title;
     std::string tag_2ch;
@@ -216,18 +257,24 @@ void Post::receive_finish()
     bool ret;
 
     // タイトル
-    regex.exec( ".*<title>([^<]*)</title>.*", str, 0, true, false );
+    icase = true;
+    newline = false; // . に改行をマッチさせる
+    regex.exec( ".*<title>([^<]*)</title>.*", str, offset, icase, newline, usemigemo, wchar );
     title = MISC::remove_space( regex.str( 1 ) );
 
     // 2chタグ
-    regex.exec( ".*2ch_X:([^\\-]*)\\-\\->.*", str, 0, false, false );
+    icase = false;
+    newline = false; // . に改行をマッチさせる
+    regex.exec( ".*2ch_X:([^\\-]*)\\-\\->.*", str, offset, icase, newline, usemigemo, wchar );
     tag_2ch = MISC::remove_space( regex.str( 1 ) );
 
     // エラー内容を取得
 
     // 一番内側の<b>〜</b>を探して取得
+    icase = true;
+    newline = false; // . に改行をマッチさせる
     m_errmsg = std::string();
-    if( regex.exec( "([^>]|[^b]>)*<b>(([^>]|[^b]>)*)</b>.*", str, 0, true, false ) ){
+    if( regex.exec( "([^>]|[^b]>)*<b>(([^>]|[^b]>)*)</b>.*", str, offset, icase, newline, usemigemo, wchar ) ){
 
         m_errmsg = regex.str( 2 );
     }
@@ -235,13 +282,17 @@ void Post::receive_finish()
     // 2ch タグで error が返った場合
     else if( tag_2ch.find( "error" ) != std::string::npos ){
 
-        if( regex.exec( "error +-->(.*)</body>", str, 0, true, false ) ) m_errmsg = regex.str( 1 );
+        icase = true;
+        newline = false; // . に改行をマッチさせる
+        if( regex.exec( "error +-->(.*)</body>", str, offset, icase, newline, usemigemo, wchar ) ) m_errmsg = regex.str( 1 );
     }
 
     // p2 型
     else if( title.find( "error" ) != std::string::npos ){
 
-        if( regex.exec( "<h4>(.*)</h4>", str, 0, true, false ) ) m_errmsg = regex.str( 1 );
+        icase = true;
+        newline = false; // . に改行をマッチさせる
+        if( regex.exec( "<h4>(.*)</h4>", str, offset, icase, newline, usemigemo, wchar ) ) m_errmsg = regex.str( 1 );
     }
 
     if( ! m_errmsg.empty() ){
@@ -249,7 +300,9 @@ void Post::receive_finish()
         m_errmsg = MISC::replace_str( m_errmsg, "\n", "" ); 
 
         // <a 〜を取り除く
-        while( regex.exec( "(.*)<a +href *= *\"([^\"]*)\" *>(.*)</a>(.*)", m_errmsg ) ){
+        icase = false;
+        newline = true;
+        while( regex.exec( "(.*)<a +href *= *\"([^\"]*)\" *>(.*)</a>(.*)", m_errmsg, offset, icase, newline, usemigemo, wchar ) ){
             m_errmsg = regex.str( 1 ) + " " + regex.str( 2 ) + " " + regex.str( 3 ) + regex.str( 4 );
         }
 
@@ -258,7 +311,9 @@ void Post::receive_finish()
         m_errmsg= MISC::replace_str( m_errmsg, "<hr>", "\n-------------------\n" );
 
         // samba秒取得
-        if( regex.exec( "ＥＲＲＯＲ +- +593 +([0-9]+) +sec", m_errmsg ) ){
+        icase = false;
+        newline = true;
+        if( regex.exec( "ＥＲＲＯＲ +- +593 +([0-9]+) +sec", m_errmsg, offset, icase, newline, usemigemo, wchar ) ){
             time_t sec = atoi( regex.str( 1 ).c_str() );
 #ifdef _DEBUG
             std::cout << "samba = " << sec << std::endl;
@@ -269,18 +324,25 @@ void Post::receive_finish()
     }
 
     // 書き込み確認
-    regex.exec( ".*<font size=\\+1 color=#FF0000>([^<]*)</font>.*", str );
+    icase = false;
+    newline = true;
+    regex.exec( ".*<font size=\\+1 color=#FF0000>([^<]*)</font>.*", str, offset, icase, newline, usemigemo, wchar );
     conf = MISC::remove_space( regex.str( 1 ) );
 
     // メッセージ本文
 
     // 2ch 型
-    ret = regex.exec( ".*</ul>.*<b>(.*)</b>.*<form.*", str, 0, false, false );
+    icase = false;
+    newline = false; // . に改行をマッチさせる
+    ret = regex.exec( ".*</ul>.*<b>(.*)</b>.*<form.*", str, offset, icase, newline, usemigemo, wchar );
 
     // 0ch 型
-    if( ! ret ) ret = regex.exec( ".*</ul>.*<b>(.*)</b>.*<input.*", str, 0, false, false );
+    icase = false;
+    newline = false; // . に改行をマッチさせる
+    if( ! ret ) ret = regex.exec( ".*</ul>.*<b>(.*)</b>.*<input.*", str, offset, icase, newline, usemigemo, wchar );
 
     msg = MISC::remove_space( regex.str( 1 ) );
+    std::list< std::string > list_cookies = SKELETON::Loadable::cookies();
 
 #ifdef _DEBUG
     std::cout << "TITLE: [" << title << "]\n";
@@ -289,7 +351,6 @@ void Post::receive_finish()
     std::cout << "MSG: [" << msg << "]\n";
     std::cout << "ERR: [" << m_errmsg << "]\n";
 
-    std::list< std::string > list_cookies = SKELETON::Loadable::cookies();
     std::list< std::string >::iterator it = list_cookies.begin();
     for( ; it != list_cookies.end(); ++it ) std::cout << "cookie : [" << (*it) << "]\n";
 
@@ -299,7 +360,7 @@ void Post::receive_finish()
     // 成功
     if( title.find( "書きこみました" ) != std::string::npos
         || tag_2ch.find( "true" ) != std::string::npos
-        || ( get_code() == HTTP_REDIRECT && ! location().empty() )  // リダイレクトされた場合
+        || ( ( get_code() == HTTP_MOVED_PERM || get_code() == HTTP_REDIRECT ) && ! location().empty() )  // リダイレクトされた場合
         ){
 
 #ifdef _DEBUG
@@ -314,7 +375,9 @@ void Post::receive_finish()
     // クッキー確認
     else if( m_count < 1 && // 永久ループ防止
         ( title.find( "書き込み確認" ) != std::string::npos
-          || tag_2ch.find( "cookie" ) != std::string::npos  ) ){
+          || tag_2ch.find( "cookie" ) != std::string::npos
+          || ( ! DBTREE::board_list_cookies_for_write( m_url ).size() && list_cookies.size() )
+            ) ){
 
         clear();
 
@@ -322,13 +385,9 @@ void Post::receive_finish()
         if( ! CONFIG::get_always_write_ok() ){
 
             std::string diagmsg = MISC::replace_str( msg, "<br>", "\n" );
+            if( diagmsg.empty() ) diagmsg = "クッキーを有功にして書き込みますか？";
 
-            SKELETON::MsgCheckDiag mdiag( MESSAGE::get_admin()->get_win(),
-                                          diagmsg,
-                                          "今後表示しない(常にOK)(_D)",
-                                          Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
-
-            mdiag.set_title( "書き込み確認" );
+            ConfirmDiag mdiag( m_url, diagmsg );
             const int ret = mdiag.run();
             mdiag.hide();
             if( ret != Gtk::RESPONSE_OK ){
@@ -348,8 +407,9 @@ void Post::receive_finish()
         if( ! keyword.empty() && m_msg.find( keyword ) == std::string::npos ) m_msg += "&" + keyword;
 
         // クッキーのセット
-        if( ! SKELETON::Loadable::cookies().empty() )
-            DBTREE::board_set_list_cookies_for_write( m_url, SKELETON::Loadable::cookies() );
+        if( list_cookies.size() ){
+            DBTREE::board_set_list_cookies_for_write( m_url, list_cookies );
+        }
 
         ++m_count; // 永久ループ防止
         post_msg();
