@@ -12,10 +12,12 @@
 #include "globalabonethreadpref.h"
 #include "fontcolorpref.h"
 #include "livepref.h"
+#include "openurldiag.h"
 
 #include "mainitempref.h"
 #include "sidebaritempref.h"
 #include "boarditempref.h"
+#include "boarditemmenupref.h"
 #include "articleitempref.h"
 #include "articleitemmenupref.h"
 #include "msgitempref.h"
@@ -32,7 +34,7 @@
 
 #include "config/aboutconfig.h"
 
-SKELETON::PrefDiag* CORE::PrefDiagFactory( Gtk::Window* parent, int type, const std::string& url )
+SKELETON::PrefDiag* CORE::PrefDiagFactory( Gtk::Window* parent, const int type, const std::string& url, const std::string command )
 {
     switch( type )
     {
@@ -78,6 +80,9 @@ SKELETON::PrefDiag* CORE::PrefDiagFactory( Gtk::Window* parent, int type, const
         case PREFDIAG_BOARDITEM:
             return new CORE::BoardItemPref( parent, url );            
 
+        case PREFDIAG_BOARDITEM_MENU:
+            return new CORE::BoardItemMenuPref( parent, url );
+
         case PREFDIAG_ARTICLEITEM:
             return new CORE::ArticleItemPref( parent, url );            
 
@@ -91,10 +96,10 @@ SKELETON::PrefDiag* CORE::PrefDiagFactory( Gtk::Window* parent, int type, const
             return new DBIMG::DelImgDiag( parent, url );
 
         case PREFDIAG_BOARD:
-            return new BOARD::Preferences( parent, url );
+            return new BOARD::Preferences( parent, url, command );
 
         case PREFDIAG_ARTICLE:
-            return new ARTICLE::Preferences( parent, url );
+            return new ARTICLE::Preferences( parent, url, command );
 
         case PREFDIAG_IMAGE:
             return new IMAGE::Preferences( parent, url );
@@ -111,8 +116,10 @@ SKELETON::PrefDiag* CORE::PrefDiagFactory( Gtk::Window* parent, int type, const
         case PREFDIAG_ABOUTCONFIG:
             return new CONFIG::AboutConfig( parent );
 
+        case PREFDIAG_OPENURL:
+            return new CORE::OpenURLDialog( url );
+
         default:
             return NULL;
     }
 }
-
