@@ -30,6 +30,7 @@ namespace CORE
         PREFDIAG_MAINITEM,
         PREFDIAG_SIDEBARITEM,
         PREFDIAG_BOARDITEM,
+        PREFDIAG_BOARDITEM_MENU,
         PREFDIAG_BOARDITEM_COLUM,
         PREFDIAG_ARTICLEITEM,
         PREFDIAG_ARTICLEITEM_MENU,
@@ -47,10 +48,12 @@ namespace CORE
 
         PREFDIAG_ABOUTCONFIG,
 
+        PREFDIAG_OPENURL,
+
         PREFDIAG_NONE
     };
     
-    SKELETON::PrefDiag* PrefDiagFactory( Gtk::Window* parent, int type, const std::string& url );
+    SKELETON::PrefDiag* PrefDiagFactory( Gtk::Window* parent, const int type, const std::string& url, const std::string command = std::string() );
 }
 
 #endif
