@@ -62,10 +62,17 @@ void PaneControl::update_position()
 
     int pos = m_paned.get_position();
 
+    // PAGE1を最大化
     if( m_mode == PANE_MAX_PAGE1 ) m_paned.set_position( get_size() );
+
+    // PAGE2を最大化
     else if( m_mode == PANE_MAX_PAGE2 && pos > 0 ) m_paned.set_position( 0 );
+
+    // 通常状態
     else if( m_mode == PANE_NORMAL ){
 
+        // ウィンドウをリサイズしたときの処理
+        // m_fixmode の値によりPAGE1とPAGE2のどちらのサイズを固定するか判断する
         int newpos = 0;
 
         if( m_fixmode == PANE_FIXSIZE_PAGE1 && pos != m_pos ){
@@ -76,6 +83,10 @@ void PaneControl::update_position()
         }
 
         if( newpos ) m_paned.set_position( newpos );
+
+#ifdef _DEBUG
+        std::cout << "newpos = " << newpos << " pos = " << m_paned.get_position() << std::endl;
+#endif
     }
 }
 
@@ -136,7 +147,11 @@ void PaneControl::set_mode( int mode )
 void PaneControl::add_remove1( bool unpack, Gtk::Widget& child )
 {
     if( unpack ) m_paned.remove( child );
-    else m_paned.add1( child );
+
+    // paned.ccg Revision 2 , Tue Jan 21 13:41:59 2003 UTC をハック
+    // pack1 を SHRINK、pack2 を EXPAND にしないとリサイズしたときに
+    // 仕切りがバタつく
+    else m_paned.pack1( child, Gtk::SHRINK );
 }
 
 
@@ -144,7 +159,7 @@ void PaneControl::add_remove1( bool unpack, Gtk::Widget& child )
 void PaneControl::add_remove2( bool unpack, Gtk::Widget& child )
 {
     if( unpack ) m_paned.remove( child );
-    else m_paned.add2( child );
+    else m_paned.pack2( child, Gtk::EXPAND );
 }
 
 
@@ -184,14 +199,20 @@ void PaneControl::button_release_event( GdkEventButton* event )
 
     // 仕切りをドラッグした場合
     else if( m_clicked && m_drag ){
-        m_mode = PANE_NORMAL;
 
-        if( m_fixmode == PANE_FIXSIZE_PAGE1 ) m_pos = m_paned.get_position();
-        else if( m_fixmode == PANE_FIXSIZE_PAGE2 ) m_pos = get_size() - m_paned.get_position();
+        if( m_mode == PANE_NORMAL ){
+
+            if( m_fixmode == PANE_FIXSIZE_PAGE1 ) m_pos = m_paned.get_position();
+            else if( m_fixmode == PANE_FIXSIZE_PAGE2 ) m_pos = get_size() - m_paned.get_position();
 
 #ifdef _DEBUG
-        std::cout << "new pos = " << m_pos << std::endl;
+            std::cout << "new pos = " << m_pos << std::endl;
 #endif
+
+            set_mode( PANE_NORMAL );
+        }
+        else if( m_mode == PANE_MAX_PAGE1 ) m_paned.set_position( get_size() );
+        else if( m_mode == PANE_MAX_PAGE2 ) m_paned.set_position( 0 );
     }
 
     m_clicked = false;
