@@ -16,6 +16,9 @@
 
 #include "jdlib/loader.h"
 
+#include "control/controlutil.h"
+#include "control/controlid.h"
+
 #ifdef HAVE_MIGEMO_H
 #include "jdlib/jdmigemo.h"
 #include "config/globalconf.h"
@@ -57,6 +60,7 @@ JDWinMain::JDWinMain( const bool init, const bool skip_setupdiag )
 
     // サイズ変更
     init_win();
+    if( SESSION::is_full_win_main() ) fullscreen();
 
     set_spacing( 4 );
 
@@ -65,6 +69,10 @@ JDWinMain::JDWinMain( const bool init, const bool skip_setupdiag )
     set_resizable( true );
     property_destroy_with_parent().set_value( false );
 
+    add_events( Gdk::BUTTON_PRESS_MASK );
+    add_events( Gdk::BUTTON_RELEASE_MASK );
+    add_events( Gdk::POINTER_MOTION_MASK );
+
     // migemo 初期化
 #ifdef HAVE_MIGEMO_H
     jd_migemo_init( CONFIG::get_migemodict_path().c_str() );
@@ -83,7 +91,13 @@ JDWinMain::~JDWinMain()
               << " w = " << get_width_win() << " h = " << get_height_win() << " max = " << is_maximized_win() << std::endl;
 #endif
 
-    save_session();
+    if( m_core ){
+
+        delete m_core;
+        m_core = NULL;
+
+        JDLIB::check_loader_alive();
+    }
 
     // migemo のクローズ
 #ifdef HAVE_MIGEMO_H
@@ -95,17 +109,6 @@ JDWinMain::~JDWinMain()
 }
 
 
-// 緊急シャットダウン
-void JDWinMain::shutdown()
-{
-#ifdef _DEBUG
-    std::cout << "JDWinMain::shutdown\n";
-#endif
-
-    if( m_core ) m_core->shutdown();
-}
-
-
 // 通常のセッション保存
 void JDWinMain::save_session()
 {
@@ -113,15 +116,7 @@ void JDWinMain::save_session()
     std::cout << "JDWinMain::save_session\n";
 #endif
 
-    if( m_core ){
-
-        delete m_core;
-        m_core = NULL;
-
-        SESSION::save_session();
-
-        JDLIB::check_loader_alive();
-    }
+    if( m_core ) m_core->save_session();
 }
 
 
@@ -149,12 +144,12 @@ const int JDWinMain::get_y_win()
     return SESSION::get_y_win_main();
 }
 
-void JDWinMain::set_x_win( int x )
+void JDWinMain::set_x_win( const int x )
 {
     SESSION::set_x_win_main( x );
 }
 
-void JDWinMain::set_y_win( int y )
+void JDWinMain::set_y_win( const int y )
 {
     SESSION::set_y_win_main( y );
 }
@@ -169,12 +164,12 @@ const int JDWinMain::get_height_win()
     return SESSION::get_height_win_main();
 }
 
-void JDWinMain::set_width_win( int width )
+void JDWinMain::set_width_win( const int width )
 {
     SESSION::set_width_win_main( width );
 }
 
-void JDWinMain::set_height_win( int height )
+void JDWinMain::set_height_win( const int height )
 {
     SESSION::set_height_win_main( height );
 }
@@ -184,7 +179,7 @@ const bool JDWinMain::is_focus_win()
     return SESSION::is_focus_win_main();
 }
 
-void JDWinMain::set_focus_win( bool set )
+void JDWinMain::set_focus_win( const bool set )
 {
     SESSION::set_focus_win_main( set );
 }
@@ -196,7 +191,7 @@ const bool JDWinMain::is_maximized_win()
 }
 
 
-void JDWinMain::set_maximized_win( bool set )
+void JDWinMain::set_maximized_win( const bool set )
 {
     SESSION::set_maximized_win_main( set );
 }
@@ -207,18 +202,30 @@ const bool JDWinMain::is_iconified_win()
     return SESSION::is_iconified_win_main();
 }
 
-void JDWinMain::set_iconified_win( bool set )
+void JDWinMain::set_iconified_win( const bool set )
 {
     SESSION::set_iconified_win_main( set );
 }
 
+
+const bool JDWinMain::is_full_win()
+{
+    return SESSION::is_full_win_main();
+}
+
+void JDWinMain::set_full_win( const bool set )
+{
+    SESSION::set_full_win_main( set );
+}
+
+
 const bool JDWinMain::is_shown_win()
 {
     return SESSION::is_shown_win_main();
 }
 
 
-void JDWinMain::set_shown_win( bool set )
+void JDWinMain::set_shown_win( const bool set )
 {
     SESSION::set_shown_win_main( set );
 }
@@ -266,3 +273,56 @@ bool JDWinMain::on_configure_event( GdkEventConfigure* event )
 
     return SKELETON::JDWindow::on_configure_event( event );
 }
+
+
+bool JDWinMain::on_button_press_event( GdkEventButton* event )
+{
+#ifdef _DEBUG
+    std::cout << "JDWinMain::on_button_press_event\n";
+#endif
+
+    // マウスジェスチャ
+    m_control.MG_start( event );
+
+    return SKELETON::JDWindow::on_button_press_event( event );
+}
+
+
+bool JDWinMain::on_button_release_event( GdkEventButton* event )
+{
+#ifdef _DEBUG
+    std::cout << "JDWinMain::on_button_release_event\n";
+#endif
+
+    const bool ret =  SKELETON::JDWindow::on_button_release_event( event );
+
+    /// マウスジェスチャ
+    const int mg = m_control.MG_end( event );
+
+    // マウスジェスチャ
+    if( mg != CONTROL::None ) operate_win( mg );
+
+    return ret;
+}
+
+
+//
+// マウスが動いた
+//
+bool JDWinMain::on_motion_notify_event( GdkEventMotion* event )
+{
+#ifdef _DEBUG
+    std::cout << "JDWinMain::on_motion_notify_event\n";
+#endif
+
+    /// マウスジェスチャ
+    m_control.MG_motion( event );
+
+    return SKELETON::JDWindow::on_motion_notify_event( event );
+}
+
+
+const bool JDWinMain::operate_win( const int control )
+{
+    return CONTROL::operate_common( control, std::string(), NULL );
+}
